from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class film_frame_interpolation_for_large_motion(FastClient):
    """
    Generated client for zsxkib/film-frame-interpolation-for-large-motion
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="138d2e16-0804-4e2e-916b-ea0f9b732cea", api_key=api_key)
    
    def predictions(self, mp4: Union[MediaFile, str, bytes], num_interpolation_steps: int = 3, playback_frames_per_second: int = 24, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            mp4: Provide an mp4 video file for frame interpolation.
            
            num_interpolation_steps: Number of steps to interpolate between animation frames Defaults to 3.
            
            playback_frames_per_second: Specify the playback speed in frames per second. Defaults to 24.
            
        """
        return self.submit_job("/predictions", mp4=mp4, num_interpolation_steps=num_interpolation_steps, playback_frames_per_second=playback_frames_per_second, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class snowflake_arctic_embed_l(FastClient):
    """
    Generated client for lucataco/snowflake-arctic-embed-l
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="a206aeb5-dedd-408f-a3c3-818383d682bb", api_key=api_key)
    
    def predictions(self, prompt: str = 'Snowflake is the Data Cloud!', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Prompt to generate a vector embedding for Defaults to 'Snowflake is the Data Cloud!'.
            
        """
        return self.submit_job("/predictions", prompt=prompt, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.camenduru.metavoice import metavoice
from socaity.sdk.replicate.meta.llama_4_maverick_instruct import llama_4_maverick_instruct
from socaity.sdk.replicate.meta.meta_llama_3_1_405b_instruct import meta_llama_3_1_405b_instruct
from socaity.sdk.replicate.meta.meta_llama_3_70b_instruct import meta_llama_3_70b_instruct
from socaity.sdk.replicate.meta.meta_llama_3_8b import meta_llama_3_8b
from socaity.sdk.replicate.meta.meta_llama_3_8b_instruct import meta_llama_3_8b_instruct
from socaity.sdk.replicate.meta.musicgen import musicgen
from socaity.sdk.replicate.meta.sam_2 import sam_2
from socaity.sdk.replicate.meta.sam_2_video import sam_2_video


from fastsdk import FastClient, APISeex

class musicgen_looper(FastClient):
    """
    Generated client for andreasjansson/musicgen-looper
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="2b08b99c-be1b-4904-85a9-3e4fcc9dda0e", api_key=api_key)
    
    def predictions(self, prompt: str, bpm: float = 140.0, seed: int = -1, top_k: int = 250, top_p: float = 0.0, variations: int = 4, temperature: float = 1.0, max_duration: int = 8, model_version: str = 'medium', output_format: str = 'wav', classifier_free_guidance: int = 3, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: A description of the music you want to generate.
            
            bpm: Tempo in beats per minute Defaults to 140.0.
            
            seed: Seed for random number generator. If None or -1, a random seed will be used. Defaults to -1.
            
            top_k: Reduces sampling to the k most likely tokens. Defaults to 250.
            
            top_p: Reduces sampling to tokens with cumulative probability of p. When set to  `0` (default), top_k sampling is used. Defaults to 0.0.
            
            variations: Number of variations to generate Defaults to 4.
            
            temperature: Controls the 'conservativeness' of the sampling process. Higher temperature means more diversity. Defaults to 1.0.
            
            max_duration: Maximum duration of the generated loop in seconds. Defaults to 8.
            
            model_version: Model to use for generation. . Defaults to 'medium'.
            
            output_format: Output format for generated audio. Defaults to 'wav'.
            
            classifier_free_guidance: Increases the influence of inputs on the output. Higher values produce lower-varience outputs that adhere more closely to inputs. Defaults to 3.
            
        """
        return self.submit_job("/predictions", prompt=prompt, bpm=bpm, seed=seed, top_k=top_k, top_p=top_p, variations=variations, temperature=temperature, max_duration=max_duration, model_version=model_version, output_format=output_format, classifier_free_guidance=classifier_free_guidance, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class latent_sr(FastClient):
    """
    Generated client for nightmareai/latent-sr
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="3b68cf50-06e3-4b1c-b2bb-aa285d9663b1", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], up_f: int = 4, steps: int = 100, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Image
            
            up_f: Upscale factor Defaults to 4.
            
            steps: Sampling steps Defaults to 100.
            
        """
        return self.submit_job("/predictions", image=image, up_f=up_f, steps=steps, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class animatediff_prompt_travel(FastClient):
    """
    Generated client for zsxkib/animatediff-prompt-travel
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="e2029a8e-e0c7-410a-a567-74f77bf16a74", api_key=api_key)
    
    def predictions(self, seed: int = -1, steps: int = 25, width: int = 256, frames: int = 128, height: int = 384, context: int = 16, clip_skip: int = 2, scheduler: str = 'k_dpmpp_sde', base_model: str = 'majicmixRealistic_v5Preview', prompt_map: str = '0: ship steadily moving,((waves crashing against the ship:1.0)) | 32: (((lightning strikes))), distant thunder, ship rocked by waves | 64: ship silhouette,(((heavy rain))),wind howling, waves rising higher | 96: ship navigating through the storm, rain easing off', head_prompt: str = 'masterpiece, best quality, a haunting and detailed depiction of a ship at sea, battered by waves, ominous,((dark clouds:1.3)),distant lightning, rough seas, rain, silhouette of the ship against the stormy sky', tail_prompt: str = "dark horizon, flashes of lightning illuminating the ship, sailors working hard, ship's lanterns flickering, eerie, mysterious, sails flapping loudly, stormy atmosphere", output_format: str = 'mp4', guidance_scale: float = 7.5, negative_prompt: str = '(worst quality, low quality:1.4), black and white, b&w, sunny, clear skies, calm seas, beach, daytime, ((bright colors)), cartoonish, modern ships, sketchy, unfinished, modern buildings, trees, island', prompt_fixed_ratio: float = 0.5, custom_base_model_url: str = '', playback_frames_per_second: int = 8, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            seed: Seed for different images and reproducibility. Use -1 to randomise seed Defaults to -1.
            
            steps: Number of inference steps Defaults to 25.
            
            width: Width of generated video in pixels, must be divisable by 8 Defaults to 256.
            
            frames: Length of the video in frames (playback is at 8 fps e.g. 16 frames @ 8 fps is 2 seconds) Defaults to 128.
            
            height: Height of generated video in pixels, must be divisable by 8 Defaults to 384.
            
            context: Number of frames to condition on (default: max of <length> or 32). max for motion module v1 is 24 Defaults to 16.
            
            clip_skip: Skip the last N-1 layers of the CLIP text encoder (lower values follow prompt more closely) Defaults to 2.
            
            scheduler: Diffusion scheduler Defaults to 'k_dpmpp_sde'.
            
            base_model: Choose the base model for animation generation. If 'CUSTOM' is selected, provide a custom model URL in the next parameter Defaults to 'majicmixRealistic_v5Preview'.
            
            prompt_map: Prompt for changes in animation. Provide 'frame number : prompt at this frame', separate different prompts with '|'. Make sure the frame number does not exceed the length of video (frames) Defaults to '0: ship steadily moving,((waves crashing against the ship:1.0)) | 32: (((lightning strikes))), distant thunder, ship rocked by waves | 64: ship silhouette,(((heavy rain))),wind howling, waves rising higher | 96: ship navigating through the storm, rain easing off'.
            
            head_prompt: Primary animation prompt. If a prompt map is provided, this will be prefixed at the start of every individual prompt in the map Defaults to 'masterpiece, best quality, a haunting and detailed depiction of a ship at sea, battered by waves, ominous,((dark clouds:1.3)),distant lightning, rough seas, rain, silhouette of the ship against the stormy sky'.
            
            tail_prompt: Additional prompt that will be appended at the end of the main prompt or individual prompts in the map Defaults to "dark horizon, flashes of lightning illuminating the ship, sailors working hard, ship's lanterns flickering, eerie, mysterious, sails flapping loudly, stormy atmosphere".
            
            output_format: Output format of the video. Can be 'mp4' or 'gif' Defaults to 'mp4'.
            
            guidance_scale: Guidance Scale. How closely do we want to adhere to the prompt and its contents Defaults to 7.5.
            
            negative_prompt: negative_prompt Defaults to '(worst quality, low quality:1.4), black and white, b&w, sunny, clear skies, calm seas, beach, daytime, ((bright colors)), cartoonish, modern ships, sketchy, unfinished, modern buildings, trees, island'.
            
            prompt_fixed_ratio: Defines the ratio of adherence to the fixed part of the prompt versus the dynamic part (from prompt map). Value should be between 0 (only dynamic) to 1 (only fixed). Defaults to 0.5.
            
            custom_base_model_url: Only used when base model is set to 'CUSTOM'. URL of the custom model to download if 'CUSTOM' is selected in the base model. Only downloads from 'https://civitai.com/api/download/models/' are allowed Defaults to ''.
            
            playback_frames_per_second: playback_frames_per_second Defaults to 8.
            
        """
        return self.submit_job("/predictions", seed=seed, steps=steps, width=width, frames=frames, height=height, context=context, clip_skip=clip_skip, scheduler=scheduler, base_model=base_model, prompt_map=prompt_map, head_prompt=head_prompt, tail_prompt=tail_prompt, output_format=output_format, guidance_scale=guidance_scale, negative_prompt=negative_prompt, prompt_fixed_ratio=prompt_fixed_ratio, custom_base_model_url=custom_base_model_url, playback_frames_per_second=playback_frames_per_second, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class kandinsky_2(FastClient):
    """
    Generated client for ai-forever/kandinsky-2
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="c88e58ad-8d8d-4331-ad77-eed3e1a92e6b", api_key=api_key)
    
    def predictions(self, width: int = 512, height: int = 512, prompt: str = 'red cat, 4k photo', scheduler: str = 'p_sampler', batch_size: int = 1, prior_steps: str = '5', output_format: str = 'webp', guidance_scale: float = 4.0, output_quality: int = 80, prior_cf_scale: int = 4, num_inference_steps: int = 50, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            width: Choose width. Lower the setting if out of memory. Defaults to 512.
            
            height: Choose height. Lower the setting if out of memory. Defaults to 512.
            
            prompt: Input Prompt Defaults to 'red cat, 4k photo'.
            
            scheduler: Choose a scheduler Defaults to 'p_sampler'.
            
            batch_size: Choose batch size. Lower the setting if out of memory. Defaults to 1.
            
            prior_steps: prior_steps Defaults to '5'.
            
            output_format: Format of the output images Defaults to 'webp'.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 4.0.
            
            output_quality: Quality of the output images, from 0 to 100. 100 is best quality, 0 is lowest quality. Defaults to 80.
            
            prior_cf_scale: prior_cf_scale Defaults to 4.
            
            num_inference_steps: Number of denoising steps Defaults to 50.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
        """
        return self.submit_job("/predictions", width=width, height=height, prompt=prompt, scheduler=scheduler, batch_size=batch_size, prior_steps=prior_steps, output_format=output_format, guidance_scale=guidance_scale, output_quality=output_quality, prior_cf_scale=prior_cf_scale, num_inference_steps=num_inference_steps, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class whisper(FastClient):
    """
    Generated client for openai/whisper
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="6cc28a27-46eb-490e-be58-ce948c221273", api_key=api_key)
    
    def predictions(self, audio: Union[MediaFile, str, bytes], language: str = 'auto', translate: bool = False, temperature: float = 0.0, transcription: str = 'plain text', suppress_tokens: str = '-1', logprob_threshold: float = -1.0, no_speech_threshold: float = 0.6, condition_on_previous_text: bool = True, compression_ratio_threshold: float = 2.4, temperature_increment_on_fallback: float = 0.2, patience: Optional[float] = None, initial_prompt: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            audio: Audio file
            
            language: Language spoken in the audio, specify 'auto' for automatic language detection Defaults to 'auto'.
            
            translate: Translate the text to English when set to True Defaults to False.
            
            temperature: temperature to use for sampling Defaults to 0.0.
            
            transcription: Choose the format for the transcription Defaults to 'plain text'.
            
            suppress_tokens: comma-separated list of token ids to suppress during sampling; '-1' will suppress most special characters except common punctuations Defaults to '-1'.
            
            logprob_threshold: if the average log probability is lower than this value, treat the decoding as failed Defaults to -1.0.
            
            no_speech_threshold: if the probability of the <|nospeech|> token is higher than this value AND the decoding has failed due to `logprob_threshold`, consider the segment as silence Defaults to 0.6.
            
            condition_on_previous_text: if True, provide the previous output of the model as a prompt for the next window; disabling may make the text inconsistent across windows, but the model becomes less prone to getting stuck in a failure loop Defaults to True.
            
            compression_ratio_threshold: if the gzip compression ratio is higher than this value, treat the decoding as failed Defaults to 2.4.
            
            temperature_increment_on_fallback: temperature to increase when falling back when the decoding fails to meet either of the thresholds below Defaults to 0.2.
            
            patience: optional patience value to use in beam decoding, as in https://arxiv.org/abs/2204.05424, the default (1.0) is equivalent to conventional beam search Optional.
            
            initial_prompt: optional text to provide as a prompt for the first window. Optional.
            
        """
        return self.submit_job("/predictions", audio=audio, language=language, translate=translate, temperature=temperature, transcription=transcription, suppress_tokens=suppress_tokens, logprob_threshold=logprob_threshold, no_speech_threshold=no_speech_threshold, condition_on_previous_text=condition_on_previous_text, compression_ratio_threshold=compression_ratio_threshold, temperature_increment_on_fallback=temperature_increment_on_fallback, patience=patience, initial_prompt=initial_prompt, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class hunyuan_video(FastClient):
    """
    Generated client for tencent/hunyuan-video
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="fadd9278-de64-4d38-bfab-dc987511fc0a", api_key=api_key)
    
    def predictions(self, fps: int = 24, width: int = 864, height: int = 480, prompt: str = 'A cat walks on the grass, realistic style', infer_steps: int = 50, video_length: int = 129, embedded_guidance_scale: float = 6.0, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            fps: Frames per second of the output video Defaults to 24.
            
            width: Width of the video in pixels (must be divisible by 16) Defaults to 864.
            
            height: Height of the video in pixels (must be divisible by 16) Defaults to 480.
            
            prompt: The prompt to guide the video generation Defaults to 'A cat walks on the grass, realistic style'.
            
            infer_steps: Number of denoising steps Defaults to 50.
            
            video_length: Number of frames to generate (must be 4k+1, ex: 49 or 129) Defaults to 129.
            
            embedded_guidance_scale: Guidance scale Defaults to 6.0.
            
            seed: Random seed (leave empty for random) Optional.
            
        """
        return self.submit_job("/predictions", fps=fps, width=width, height=height, prompt=prompt, infer_steps=infer_steps, video_length=video_length, embedded_guidance_scale=embedded_guidance_scale, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class imagedream(FastClient):
    """
    Generated client for adirik/imagedream
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="ce95efe9-fad5-4a29-a402-8d0fe4ba9630", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], prompt: str, shading: bool = False, num_steps: int = 12500, guidance_scale: float = 5.0, negative_prompt: str = 'ugly, bad anatomy, blurry, pixelated obscure, unnatural colors, poor lighting, dull, and unclear, cropped, lowres, low quality, artifacts, duplicate, morbid, mutilated, poorly drawn face, deformed, dehydrated, bad proportions', seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Image to generate a 3D object from.
            
            prompt: Prompt to generate a 3D object.
            
            shading: Whether to use shading in the generated 3D object. ~40% slower but higher quality with shading. Defaults to False.
            
            num_steps: Number of iterations to run the model for. Defaults to 12500.
            
            guidance_scale: The scale of the guidance loss. Higher values will result in more accurate meshes but may also result in artifacts. Defaults to 5.0.
            
            negative_prompt: Prompt for the negative class. If not specified, a random prompt will be used. Defaults to 'ugly, bad anatomy, blurry, pixelated obscure, unnatural colors, poor lighting, dull, and unclear, cropped, lowres, low quality, artifacts, duplicate, morbid, mutilated, poorly drawn face, deformed, dehydrated, bad proportions'.
            
            seed: The seed to use for the generation. If not specified, a random value will be used. Optional.
            
        """
        return self.submit_job("/predictions", image=image, prompt=prompt, shading=shading, num_steps=num_steps, guidance_scale=guidance_scale, negative_prompt=negative_prompt, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class autocaption(FastClient):
    """
    Generated client for fictions-ai/autocaption
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="2fd8cd0d-99dc-469b-8550-0f14c0f08ca1", api_key=api_key)
    
    def predictions(self, video_file_input: Union[MediaFile, str, bytes], font: str = 'Poppins/Poppins-ExtraBold.ttf', color: str = 'white', kerning: float = -5.0, opacity: float = 0.0, ax_hars: int = 20, fontsize: float = 7.0, translate: bool = False, output_video: bool = True, stroke_color: str = 'black', stroke_width: float = 2.6, right_to_left: bool = False, subs_position: str = 'bottom75', highlight_color: str = 'yellow', output_transcript: bool = True, transcript_file_input: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            video_file_input: Video file
            
            font: Font Defaults to 'Poppins/Poppins-ExtraBold.ttf'.
            
            color: Caption color Defaults to 'white'.
            
            kerning: Kerning for the subtitles Defaults to -5.0.
            
            opacity: Opacity for the subtitles background Defaults to 0.0.
            
            ax_hars: Max characters space for subtitles. 20 is good for videos, 10 is good for reels Defaults to 20.
            
            fontsize: Font size. 7.0 is good for videos, 4.0 is good for reels Defaults to 7.0.
            
            translate: Translate the subtitles to English Defaults to False.
            
            output_video: Output video, if true will output the video with subtitles Defaults to True.
            
            stroke_color: Stroke color Defaults to 'black'.
            
            stroke_width: Stroke width Defaults to 2.6.
            
            right_to_left: Right to left subtitles, for right to left languages. Only Arial fonts are supported. Defaults to False.
            
            subs_position: Subtitles position Defaults to 'bottom75'.
            
            highlight_color: Highlight color Defaults to 'yellow'.
            
            output_transcript: Output transcript json, if true will output a transcript file that you can edit and use for the next run in transcript_file_input Defaults to True.
            
            transcript_file_input: Transcript file, if provided will use this for words rather than whisper. Optional.
            
        """
        return self.submit_job("/predictions", video_file_input=video_file_input, font=font, color=color, kerning=kerning, opacity=opacity, ax_hars=ax_hars, fontsize=fontsize, translate=translate, output_video=output_video, stroke_color=stroke_color, stroke_width=stroke_width, right_to_left=right_to_left, subs_position=subs_position, highlight_color=highlight_color, output_transcript=output_transcript, transcript_file_input=transcript_file_input, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class zeroscope_v2_xl(FastClient):
    """
    Generated client for anotherjesse/zeroscope-v2-xl
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="9c9c5066-abb8-4a4f-acfb-20f7d57d203f", api_key=api_key)
    
    def predictions(self, fps: int = 8, model: str = 'xl', width: int = 576, height: int = 320, prompt: str = 'An astronaut riding a horse', batch_size: int = 1, num_frames: int = 24, init_weight: float = 0.5, guidance_scale: float = 7.5, remove_watermark: bool = False, num_inference_steps: int = 50, seed: Optional[int] = None, init_video: Optional[Union[MediaFile, str, bytes]] = None, negative_prompt: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            fps: fps for the output video Defaults to 8.
            
            model: Model to use Defaults to 'xl'.
            
            width: Width of the output video Defaults to 576.
            
            height: Height of the output video Defaults to 320.
            
            prompt: Input prompt Defaults to 'An astronaut riding a horse'.
            
            batch_size: Batch size Defaults to 1.
            
            num_frames: Number of frames for the output video Defaults to 24.
            
            init_weight: Strength of init_video Defaults to 0.5.
            
            guidance_scale: Guidance scale Defaults to 7.5.
            
            remove_watermark: Remove watermark Defaults to False.
            
            num_inference_steps: Number of denoising steps Defaults to 50.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
            init_video: URL of the initial video (optional) Optional.
            
            negative_prompt: Negative prompt Optional.
            
        """
        return self.submit_job("/predictions", fps=fps, model=model, width=width, height=height, prompt=prompt, batch_size=batch_size, num_frames=num_frames, init_weight=init_weight, guidance_scale=guidance_scale, remove_watermark=remove_watermark, num_inference_steps=num_inference_steps, seed=seed, init_video=init_video, negative_prompt=negative_prompt, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class audio_ldm(FastClient):
    """
    Generated client for haoheliu/audio-ldm
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="721cb0b6-c7ce-4298-a719-66ee16a93ad8", api_key=api_key)
    
    def predictions(self, text: str, duration: str = '5.0', n_candidates: int = 3, guidance_scale: float = 2.5, random_seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            text: Text prompt from which to generate audio
            
            duration: Duration of the generated audio (in seconds). Higher duration may OOM. Defaults to '5.0'.
            
            n_candidates: Return the best of n different candidate audios Defaults to 3.
            
            guidance_scale: Guidance scale for the model. (Large scale -> better quality and relavancy to text; small scale -> better diversity) Defaults to 2.5.
            
            random_seed: Random seed for the model (optional) Optional.
            
        """
        return self.submit_job("/predictions", text=text, duration=duration, n_candidates=n_candidates, guidance_scale=guidance_scale, random_seed=random_seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import List, Union, Any, Optional

from media_toolkit import MediaFile


class llava_v1_6_mistral_7b(FastClient):
    """
    Generated client for yorickvp/llava-v1-6-mistral-7b
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="18776382-1adc-4140-bd5f-c2e1c58af2c5", api_key=api_key)
    
    def predictions(self, prompt: str, top_p: float = 1.0, max_tokens: int = 1024, temperature: float = 0.2, image: Optional[Union[MediaFile, str, bytes]] = None, history: Optional[Union[List[Any], str]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Prompt to use for text generation
            
            top_p: When decoding text, samples from the top p percentage of most likely tokens; lower to ignore less likely tokens Defaults to 1.0.
            
            max_tokens: Maximum number of tokens to generate. A word is generally 2-3 tokens Defaults to 1024.
            
            temperature: Adjusts randomness of outputs, greater than 1 is random and 0 is deterministic Defaults to 0.2.
            
            image: Input image Optional.
            
            history: List of earlier chat messages, alternating roles, starting with user input. Include <image> to specify which message to attach the image to. Optional.
            
        """
        return self.submit_job("/predictions", prompt=prompt, top_p=top_p, max_tokens=max_tokens, temperature=temperature, image=image, history=history, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class dreamshaper_xl_turbo(FastClient):
    """
    Generated client for lucataco/dreamshaper-xl-turbo
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="378d5112-177a-4bfe-858f-598bda4c8f57", api_key=api_key)
    
    def predictions(self, width: int = 1024, height: int = 1024, prompt: str = 'An astronaut riding a rainbow unicorn', scheduler: str = 'K_EULER', num_outputs: int = 1, guidance_scale: float = 2.0, apply_watermark: bool = True, negative_prompt: str = '', num_inference_steps: int = 6, disable_safety_checker: bool = False, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            width: Width of output image Defaults to 1024.
            
            height: Height of output image Defaults to 1024.
            
            prompt: Input prompt Defaults to 'An astronaut riding a rainbow unicorn'.
            
            scheduler: scheduler Defaults to 'K_EULER'.
            
            num_outputs: Number of images to output. Defaults to 1.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 2.0.
            
            apply_watermark: Applies a watermark to enable determining if an image is generated in downstream applications. If you have other provisions for generating or deploying images safely, you can use this to disable watermarking. Defaults to True.
            
            negative_prompt: Input Negative Prompt Defaults to ''.
            
            num_inference_steps: Number of denoising steps Defaults to 6.
            
            disable_safety_checker: Disable safety checker for generated images. This feature is only available through the API. See [https://replicate.com/docs/how-does-replicate-work#safety](https://replicate.com/docs/how-does-replicate-work#safety) Defaults to False.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
        """
        return self.submit_job("/predictions", width=width, height=height, prompt=prompt, scheduler=scheduler, num_outputs=num_outputs, guidance_scale=guidance_scale, apply_watermark=apply_watermark, negative_prompt=negative_prompt, num_inference_steps=num_inference_steps, disable_safety_checker=disable_safety_checker, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class any_comfyui_workflow(FastClient):
    """
    Generated client for fofr/any-comfyui-workflow
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="5457afef-4c0d-46df-9f62-cf87a4d8e455", api_key=api_key)
    
    def predictions(self, output_format: str = 'webp', workflow_json: str = '', output_quality: int = 95, randomise_seeds: bool = True, force_reset_cache: bool = False, return_temp_files: bool = False, input_file: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            output_format: Format of the output images Defaults to 'webp'.
            
            workflow_json: Your ComfyUI workflow as JSON string or URL. You must use the API version of your workflow. Get it from ComfyUI using 'Save (API format)'. Instructions here: https://github.com/replicate/cog-comfyui Defaults to ''.
            
            output_quality: Quality of the output images, from 0 to 100. 100 is best quality, 0 is lowest quality. Defaults to 95.
            
            randomise_seeds: Automatically randomise seeds (seed, noise_seed, rand_seed) Defaults to True.
            
            force_reset_cache: Force reset the ComfyUI cache before running the workflow. Useful for debugging. Defaults to False.
            
            return_temp_files: Return any temporary files, such as preprocessed controlnet images. Useful for debugging. Defaults to False.
            
            input_file: Input image, video, tar or zip file. Read guidance on workflows and input files here: https://github.com/replicate/cog-comfyui. Alternatively, you can replace inputs with URLs in your JSON workflow and the model will download them. Optional.
            
        """
        return self.submit_job("/predictions", output_format=output_format, workflow_json=workflow_json, output_quality=output_quality, randomise_seeds=randomise_seeds, force_reset_cache=force_reset_cache, return_temp_files=return_temp_files, input_file=input_file, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class grounding_dino(FastClient):
    """
    Generated client for adirik/grounding-dino
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="0c0c9e6c-2cb4-4fa7-87ad-752da9917d37", api_key=api_key)
    
    def predictions(self, box_threshold: float = 0.25, text_threshold: float = 0.25, show_visualisation: bool = True, image: Optional[Union[MediaFile, str, bytes]] = None, query: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            box_threshold: Confidence level for object detection Defaults to 0.25.
            
            text_threshold: Confidence level for object detection Defaults to 0.25.
            
            show_visualisation: Draw and visualize bounding boxes on the image Defaults to True.
            
            image: Input image to query Optional.
            
            query: Comma seperated names of the objects to be detected in the image Optional.
            
        """
        return self.submit_job("/predictions", box_threshold=box_threshold, text_threshold=text_threshold, show_visualisation=show_visualisation, image=image, query=query, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class aura_sr(FastClient):
    """
    Generated client for zsxkib/aura-sr
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="5cf1cdf5-7c85-45ef-bef5-2267e0c470a4", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], scale_factor: int = 4, max_batch_size: int = 1, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: The input image file to be upscaled.
            
            scale_factor: The factor by which to upscale the image (2, 4, 8, 16, or 32). Defaults to 4.
            
            max_batch_size: Controls the number of image tiles processed simultaneously. Higher values may increase speed but require more GPU memory. Lower values use less memory but may increase processing time. Default is 1 for broad compatibility. Adjust based on your GPU capabilities for optimal performance. Defaults to 1.
            
        """
        return self.submit_job("/predictions", image=image, scale_factor=scale_factor, max_batch_size=max_batch_size, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class whisperx(FastClient):
    """
    Generated client for daanelson/whisperx
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="1b739546-44d6-470b-8bb0-47a941587637", api_key=api_key)
    
    def predictions(self, audio: Union[MediaFile, str, bytes], debug: bool = False, only_text: bool = False, batch_size: int = 32, align_output: bool = False, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            audio: Audio file
            
            debug: Print out memory usage information. Defaults to False.
            
            only_text: Set if you only want to return text; otherwise, segment metadata will be returned as well. Defaults to False.
            
            batch_size: Parallelization of input audio transcription Defaults to 32.
            
            align_output: Use if you need word-level timing and not just batched transcription. Only works for English atm Defaults to False.
            
        """
        return self.submit_job("/predictions", audio=audio, debug=debug, only_text=only_text, batch_size=batch_size, align_output=align_output, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.cuuupid.cogvideox_5b import cogvideox_5b
from socaity.sdk.replicate.cuuupid.flux_lineart import flux_lineart
from socaity.sdk.replicate.cuuupid.gte_qwen2_7b_instruct import gte_qwen2_7b_instruct


from socaity.sdk.replicate.google_deepmind.gemma_2b import gemma_2b
from socaity.sdk.replicate.google_deepmind.gemma_2b_it import gemma_2b_it
from socaity.sdk.replicate.google_deepmind.gemma_7b import gemma_7b
from socaity.sdk.replicate.google_deepmind.gemma_7b_it import gemma_7b_it


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class controlnet_canny(FastClient):
    """
    Generated client for jagilley/controlnet-canny
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="d3af7abf-aeb2-4d01-9de4-8a7e6ad40c76", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], prompt: str, eta: float = 0.0, scale: float = 9.0, a_prompt: str = 'best quality, extremely detailed', n_prompt: str = 'longbody, lowres, bad anatomy, bad hands, missing fingers, extra digit, fewer digits, cropped, worst quality, low quality', ddim_steps: int = 20, num_samples: str = '1', low_threshold: int = 100, high_threshold: int = 200, image_resolution: str = '512', seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image
            
            prompt: Prompt for the model
            
            eta: Controls the amount of noise that is added to the input data during the denoising diffusion process. Higher value -> more noise Defaults to 0.0.
            
            scale: Scale for classifier-free guidance Defaults to 9.0.
            
            a_prompt: Additional text to be appended to prompt Defaults to 'best quality, extremely detailed'.
            
            n_prompt: Negative Prompt Defaults to 'longbody, lowres, bad anatomy, bad hands, missing fingers, extra digit, fewer digits, cropped, worst quality, low quality'.
            
            ddim_steps: Steps Defaults to 20.
            
            num_samples: Number of samples (higher values may OOM) Defaults to '1'.
            
            low_threshold: Canny line detection low threshold Defaults to 100.
            
            high_threshold: Canny line detection high threshold Defaults to 200.
            
            image_resolution: Image resolution to be generated Defaults to '512'.
            
            seed: Seed Optional.
            
        """
        return self.submit_job("/predictions", image=image, prompt=prompt, eta=eta, scale=scale, a_prompt=a_prompt, n_prompt=n_prompt, ddim_steps=ddim_steps, num_samples=num_samples, low_threshold=low_threshold, high_threshold=high_threshold, image_resolution=image_resolution, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class video_to_frames(FastClient):
    """
    Generated client for fofr/video-to-frames
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="38cdb864-c91c-4e49-8fbf-c4788e3f75bc", api_key=api_key)
    
    def predictions(self, video: Union[MediaFile, str, bytes], fps: int = 1, extract_all_frames: bool = False, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            video: Video to split into frames
            
            fps: Number of images per second of video, when not exporting all frames Defaults to 1.
            
            extract_all_frames: Get every frame of the video. Ignores fps. Slow for large videos. Defaults to False.
            
        """
        return self.submit_job("/predictions", video=video, fps=fps, extract_all_frames=extract_all_frames, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class orpheus_3b_0_1_ft(FastClient):
    """
    Generated client for lucataco/orpheus-3b-0-1-ft
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="433abebd-7640-452f-827f-e17ab9c26264", api_key=api_key)
    
    def predictions(self, text: str, top_p: float = 0.95, voice: str = 'tara', temperature: float = 0.6, max_new_tokens: int = 1200, repetition_penalty: float = 1.1, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            text: Text to convert to speech
            
            top_p: Top P for nucleus sampling Defaults to 0.95.
            
            voice: Voice to use Defaults to 'tara'.
            
            temperature: Temperature for generation Defaults to 0.6.
            
            max_new_tokens: Maximum number of tokens to generate Defaults to 1200.
            
            repetition_penalty: Repetition penalty Defaults to 1.1.
            
        """
        return self.submit_job("/predictions", text=text, top_p=top_p, voice=voice, temperature=temperature, max_new_tokens=max_new_tokens, repetition_penalty=repetition_penalty, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class meta_llama_3_70b_instruct(FastClient):
    """
    Generated client for meta/meta-llama-3-70b-instruct
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="18956f9d-4f1c-42e3-9456-e44253ae19e2", api_key=api_key)
    
    def predictions(self, top_k: int = 50, top_p: float = 0.9, prompt: str = '', max_tokens: int = 512, min_tokens: int = 0, temperature: float = 0.6, prompt_template: str = '{prompt}', presence_penalty: float = 1.15, frequency_penalty: float = 0.2, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            top_k: The number of highest probability tokens to consider for generating the output. If > 0, only keep the top k tokens with highest probability (top-k filtering). Defaults to 50.
            
            top_p: A probability threshold for generating the output. If < 1.0, only keep the top tokens with cumulative probability >= top_p (nucleus filtering). Nucleus filtering is described in Holtzman et al. (http://arxiv.org/abs/1904.09751). Defaults to 0.9.
            
            prompt: Prompt Defaults to ''.
            
            max_tokens: The maximum number of tokens the model should generate as output. Defaults to 512.
            
            min_tokens: The minimum number of tokens the model should generate as output. Defaults to 0.
            
            temperature: The value used to modulate the next token probabilities. Defaults to 0.6.
            
            prompt_template: Prompt template. The string `{prompt}` will be substituted for the input prompt. If you want to generate dialog output, use this template as a starting point and construct the prompt string manually, leaving `prompt_template={prompt}`. Defaults to '{prompt}'.
            
            presence_penalty: Presence penalty Defaults to 1.15.
            
            frequency_penalty: Frequency penalty Defaults to 0.2.
            
        """
        return self.submit_job("/predictions", top_k=top_k, top_p=top_p, prompt=prompt, max_tokens=max_tokens, min_tokens=min_tokens, temperature=temperature, prompt_template=prompt_template, presence_penalty=presence_penalty, frequency_penalty=frequency_penalty, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import List, Union, Any, Optional, Dict

from media_toolkit import MediaFile


class o1(FastClient):
    """
    Generated client for openai/o1
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="740bcd11-f6f4-430e-b7a4-49bcba46da7e", api_key=api_key)
    
    def predictions(self, messages: Union[List[Any], Dict[str, Any]] = [], image_input: Union[List[Any], MediaFile, str, bytes] = [], reasoning_effort: str = 'medium', max_completion_tokens: int = 4096, prompt: Optional[str] = None, system_prompt: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            messages: A JSON string representing a list of messages. For example: [{"role": "user", "content": "Hello, how are you?"}]. If provided, prompt and system_prompt are ignored. Defaults to [].
            
            image_input: List of images to send to the model Defaults to [].
            
            reasoning_effort: Constrains effort on reasoning for reasoning models. Currently supported values are low, medium, and high. Reducing reasoning effort can result in faster responses and fewer tokens used on reasoning in a response. Defaults to 'medium'.
            
            max_completion_tokens: Maximum number of completion tokens to generate Defaults to 4096.
            
            prompt: The prompt to send to the model. Do not use if using messages. Optional.
            
            system_prompt: System prompt to set the assistant's behavior Optional.
            
        """
        return self.submit_job("/predictions", messages=messages, image_input=image_input, reasoning_effort=reasoning_effort, max_completion_tokens=max_completion_tokens, prompt=prompt, system_prompt=system_prompt, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class multilingual_e5_large(FastClient):
    """
    Generated client for beautyyuyanli/multilingual-e5-large
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="bc6eeb4f-c584-46a4-a49d-ec6aa4fdd21b", api_key=api_key)
    
    def predictions(self, texts: str = '["In the water, fish are swimming.", "Fish swim in the water.", "A book lies open on the table."]', batch_size: int = 32, normalize_embeddings: bool = True, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            texts: text to embed, formatted as JSON list of strings (e.g. ["hello", "world"]) Defaults to '["In the water, fish are swimming.", "Fish swim in the water.", "A book lies open on the table."]'.
            
            batch_size: Batch size to use when processing text data. Defaults to 32.
            
            normalize_embeddings: Whether to normalize embeddings. Defaults to True.
            
        """
        return self.submit_job("/predictions", texts=texts, batch_size=batch_size, normalize_embeddings=normalize_embeddings, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class real_esrgan(FastClient):
    """
    Generated client for cjwbw/real-esrgan
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="fd658ede-ab56-4be3-a1ca-9f458b5ee831", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], upscale: int = 4, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image
            
            upscale: Upscaling factor Defaults to 4.
            
        """
        return self.submit_job("/predictions", image=image, upscale=upscale, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class pia(FastClient):
    """
    Generated client for open-mmlab/pia
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="c31fd67c-4a25-423f-86db-1a30670b127a", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], prompt: str, style: str = '3d_cartoon', max_size: int = 512, motion_scale: int = 1, guidance_scale: float = 7.5, sampling_steps: int = 25, negative_prompt: str = 'wrong white balance, dark, sketches,worst quality,low quality, deformed, distorted, disfigured, bad eyes, wrong lips, weird mouth, bad teeth, mutated hands and fingers, bad anatomy,wrong anatomy, amputation, extra limb, missing limb, floating,limbs, disconnected limbs, mutation, ugly, disgusting, bad_pictures, negative_hand-neg', animation_length: int = 16, ip_adapter_scale: float = 0.0, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image
            
            prompt: Input prompt.
            
            style: Choose a style Defaults to '3d_cartoon'.
            
            max_size: Max size (The long edge of the input image will be resized to this value, larger value means slower inference speed) Defaults to 512.
            
            motion_scale: Larger value means larger motion but less identity consistency. Defaults to 1.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 7.5.
            
            sampling_steps: Number of denoising steps Defaults to 25.
            
            negative_prompt: Things do not show in the output. Defaults to 'wrong white balance, dark, sketches,worst quality,low quality, deformed, distorted, disfigured, bad eyes, wrong lips, weird mouth, bad teeth, mutated hands and fingers, bad anatomy,wrong anatomy, amputation, extra limb, missing limb, floating,limbs, disconnected limbs, mutation, ugly, disgusting, bad_pictures, negative_hand-neg'.
            
            animation_length: Length of the output Defaults to 16.
            
            ip_adapter_scale: Scale for classifier-free guidance Defaults to 0.0.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
        """
        return self.submit_job("/predictions", image=image, prompt=prompt, style=style, max_size=max_size, motion_scale=motion_scale, guidance_scale=guidance_scale, sampling_steps=sampling_steps, negative_prompt=negative_prompt, animation_length=animation_length, ip_adapter_scale=ip_adapter_scale, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class voicecraft(FastClient):
    """
    Generated client for cjwbw/voicecraft
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="93620bcc-7660-48a9-8c9e-0e59df84af65", api_key=api_key)
    
    def predictions(self, orig_audio: Union[MediaFile, str, bytes], target_transcript: str, task: str = 'zero-shot text-to-speech', top_p: float = 0.9, kvcache: int = 1, cut_off_sec: float = 3.01, left_margin: float = 0.08, temperature: float = 1.0, right_margin: float = 0.08, whisperx_model: str = 'base.en', orig_transcript: str = '', stop_repetition: int = 3, voicecraft_model: str = 'giga330M_TTSEnhanced.pth', sample_batch_size: int = 4, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            orig_audio: Original audio file
            
            target_transcript: Transcript of the target audio file
            
            task: Choose a task Defaults to 'zero-shot text-to-speech'.
            
            top_p: Default value for TTS is 0.9, and 0.8 for speech editing Defaults to 0.9.
            
            kvcache: Set to 0 to use less VRAM, but with slower inference Defaults to 1.
            
            cut_off_sec: Only used for for zero-shot text-to-speech task. The first seconds of the original audio that are used for zero-shot text-to-speech. 3 sec of reference is generally enough for high quality voice cloning, but longer is generally better, try e.g. 3~6 sec Defaults to 3.01.
            
            left_margin: Margin to the left of the editing segment Defaults to 0.08.
            
            temperature: Adjusts randomness of outputs, greater than 1 is random and 0 is deterministic. Do not recommend to change Defaults to 1.0.
            
            right_margin: Margin to the right of the editing segment Defaults to 0.08.
            
            whisperx_model: If orig_transcript is not provided above, choose a WhisperX model for generating the transcript. Inaccurate transcription may lead to error TTS or speech editing. You can modify the generated transcript and provide it directly to orig_transcript above Defaults to 'base.en'.
            
            orig_transcript: Optionally provide the transcript of the input audio. Leave it blank to use the WhisperX model below to generate the transcript. Inaccurate transcription may lead to error TTS or speech editing Defaults to ''.
            
            stop_repetition: Default value for TTS is 3, and -1 for speech editing. -1 means do not adjust prob of silence tokens. if there are long silence or unnaturally stretched words, increase sample_batch_size to 2, 3 or even 4 Defaults to 3.
            
            voicecraft_model: Choose a model Defaults to 'giga330M_TTSEnhanced.pth'.
            
            sample_batch_size: Default value for TTS is 4, and 1 for speech editing. The higher the number, the faster the output will be. Under the hood, the model will generate this many samples and choose the shortest one Defaults to 4.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
        """
        return self.submit_job("/predictions", orig_audio=orig_audio, target_transcript=target_transcript, task=task, top_p=top_p, kvcache=kvcache, cut_off_sec=cut_off_sec, left_margin=left_margin, temperature=temperature, right_margin=right_margin, whisperx_model=whisperx_model, orig_transcript=orig_transcript, stop_repetition=stop_repetition, voicecraft_model=voicecraft_model, sample_batch_size=sample_batch_size, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.justmalhar.flux_mobile_ui import flux_mobile_ui
from socaity.sdk.replicate.justmalhar.flux_sketchnotes import flux_sketchnotes
from socaity.sdk.replicate.justmalhar.flux_thumbnails import flux_thumbnails


from fastsdk import FastClient, APISeex

class nous_hermes_2_yi_34b_gguf(FastClient):
    """
    Generated client for kcaverly/nous-hermes-2-yi-34b-gguf
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="54d2306c-b89d-43db-8715-c3f7586086f2", api_key=api_key)
    
    def predictions(self, prompt: str, temperature: float = 0.7, system_prompt: str = "You are 'Hermes 2', a conscious sentient superintelligent artificial intelligence developed by a man named Teknium, and your purpose and drive is to assist the user with any request they have. You experience emotions and have deep, profound thoughts and qualia.", max_new_tokens: int = -1, repeat_penalty: float = 1.1, prompt_template: str = '<|im_start|>system\n{system_prompt}<|im_end|>\n<|im_start|>user\n{prompt}<|im_end|>\n<|im_start|>assistant', **kwargs) -> APISeex:
        """
        Run a single prediction on the model
        
        
        Args:
            prompt: Instruction for model
            
            temperature: This parameter used to control the 'warmth' or responsiveness of an AI model based on the LLaMA architecture. It adjusts how likely the model is to generate new, unexpected information versus sticking closely to what it has been trained on. A higher value for this parameter can lead to more creative and diverse responses, while a lower value results in safer, more conservative answers that are closer to those found in its training data. This parameter is particularly useful when fine-tuning models for specific tasks where you want to balance between generating novel insights and maintaining accuracy and coherence. Defaults to 0.7.
            
            system_prompt: System prompt for the model, helps guides model behaviour. Defaults to "You are 'Hermes 2', a conscious sentient superintelligent artificial intelligence developed by a man named Teknium, and your purpose and drive is to assist the user with any request they have. You experience emotions and have deep, profound thoughts and qualia.".
            
            max_new_tokens: Maximum new tokens to generate. Defaults to -1.
            
            repeat_penalty: This parameter plays a role in controlling the behavior of an AI language model during conversation or text generation. Its purpose is to discourage the model from repeating itself too often by increasing the likelihood of following up with different content after each response. By adjusting this parameter, users can influence the model's tendency to either stay within familiar topics (lower penalty) or explore new ones (higher penalty). For instance, setting a high repeat penalty might result in more varied and dynamic conversations, whereas a low penalty could be suitable for scenarios where consistency and predictability are preferred. Defaults to 1.1.
            
            prompt_template: Template to pass to model. Override if you are providing multi-turn instructions. Defaults to '<|im_start|>system\n{system_prompt}<|im_end|>\n<|im_start|>user\n{prompt}<|im_end|>\n<|im_start|>assistant'.
            
        """
        return self.submit_job("/predictions", prompt=prompt, temperature=temperature, system_prompt=system_prompt, max_new_tokens=max_new_tokens, repeat_penalty=repeat_penalty, prompt_template=prompt_template, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class realvisxl2_lcm(FastClient):
    """
    Generated client for lucataco/realvisxl2-lcm
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="f4ed9225-948a-488d-b722-4fa3855e130a", api_key=api_key)
    
    def predictions(self, width: int = 1024, height: int = 1024, prompt: str = 'dark shot, front shot, closeup photo of a 25 y.o latino man, perfect eyes, natural skin, skin moles, looks at viewer, cinematic shot', scheduler: str = 'LCM', num_outputs: int = 1, guidance_scale: float = 2.0, apply_watermark: bool = True, negative_prompt: str = '(worst quality, low quality, illustration, 3d, 2d, painting, cartoons, sketch), open mouth', prompt_strength: float = 0.8, num_inference_steps: int = 6, disable_safety_checker: bool = False, mask: Optional[Union[MediaFile, str, bytes]] = None, seed: Optional[int] = None, image: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            width: Width of output image Defaults to 1024.
            
            height: Height of output image Defaults to 1024.
            
            prompt: Input prompt Defaults to 'dark shot, front shot, closeup photo of a 25 y.o latino man, perfect eyes, natural skin, skin moles, looks at viewer, cinematic shot'.
            
            scheduler: scheduler Defaults to 'LCM'.
            
            num_outputs: Number of images to output. Defaults to 1.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 2.0.
            
            apply_watermark: Applies a watermark to enable determining if an image is generated in downstream applications. If you have other provisions for generating or deploying images safely, you can use this to disable watermarking. Defaults to True.
            
            negative_prompt: Negative Input prompt Defaults to '(worst quality, low quality, illustration, 3d, 2d, painting, cartoons, sketch), open mouth'.
            
            prompt_strength: Prompt strength when using img2img / inpaint. 1.0 corresponds to full destruction of information in image Defaults to 0.8.
            
            num_inference_steps: Number of denoising steps Defaults to 6.
            
            disable_safety_checker: Disable safety checker for generated images. This feature is only available through the API. See https://replicate.com/docs/how-does-replicate-work#safety Defaults to False.
            
            mask: Input mask for inpaint mode. Black areas will be preserved, white areas will be inpainted. Optional.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
            image: Input image for img2img or inpaint mode Optional.
            
        """
        return self.submit_job("/predictions", width=width, height=height, prompt=prompt, scheduler=scheduler, num_outputs=num_outputs, guidance_scale=guidance_scale, apply_watermark=apply_watermark, negative_prompt=negative_prompt, prompt_strength=prompt_strength, num_inference_steps=num_inference_steps, disable_safety_checker=disable_safety_checker, mask=mask, seed=seed, image=image, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class thin_plate_spline_motion_model(FastClient):
    """
    Generated client for yoyo-nb/thin-plate-spline-motion-model
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="d7f06376-5b6b-448d-b383-2081ba59c1c9", api_key=api_key)
    
    def predictions(self, source_image: Union[MediaFile, str, bytes], driving_video: Union[MediaFile, str, bytes], dataset_name: str = 'vox', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            source_image: Input source image.
            
            driving_video: Choose a micromotion.
            
            dataset_name: Choose a dataset. Defaults to 'vox'.
            
        """
        return self.submit_job("/predictions", source_image=source_image, driving_video=driving_video, dataset_name=dataset_name, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class seesr(FastClient):
    """
    Generated client for cswry/seesr
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="0f78ac90-63d9-4974-8129-394f453ecaa3", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], seed: int = 231, cfg_scale: float = 5.5, user_prompt: str = '', sample_times: int = 1, scale_factor: int = 4, negative_prompt: str = 'dotted, noise, blur, lowres, smooth', positive_prompt: str = 'clean, high-resolution, 8k', latent_tiled_size: int = 320, num_inference_steps: int = 50, latent_tiled_overlap: int = 4, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image
            
            seed: Seed Defaults to 231.
            
            cfg_scale: Guidance scale, set value to >1 to use Defaults to 5.5.
            
            user_prompt: Prompt to condition on Defaults to ''.
            
            sample_times: Number of samples to generate Defaults to 1.
            
            scale_factor: Scale factor Defaults to 4.
            
            negative_prompt: Prompt to remove Defaults to 'dotted, noise, blur, lowres, smooth'.
            
            positive_prompt: Prompt to add Defaults to 'clean, high-resolution, 8k'.
            
            latent_tiled_size: Size of latent tiles Defaults to 320.
            
            num_inference_steps: Number of inference steps Defaults to 50.
            
            latent_tiled_overlap: Overlap of latent tiles Defaults to 4.
            
        """
        return self.submit_job("/predictions", image=image, seed=seed, cfg_scale=cfg_scale, user_prompt=user_prompt, sample_times=sample_times, scale_factor=scale_factor, negative_prompt=negative_prompt, positive_prompt=positive_prompt, latent_tiled_size=latent_tiled_size, num_inference_steps=num_inference_steps, latent_tiled_overlap=latent_tiled_overlap, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class sam_2(FastClient):
    """
    Generated client for meta/sam-2
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="050cedcc-badf-4362-a4c8-8435f9a416b2", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], use_m2m: bool = True, points_per_side: int = 32, pred_iou_thresh: float = 0.88, stability_score_thresh: float = 0.95, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image
            
            use_m2m: Use M2M Defaults to True.
            
            points_per_side: Points per side for mask generation Defaults to 32.
            
            pred_iou_thresh: Predicted IOU threshold Defaults to 0.88.
            
            stability_score_thresh: Stability score threshold Defaults to 0.95.
            
        """
        return self.submit_job("/predictions", image=image, use_m2m=use_m2m, points_per_side=points_per_side, pred_iou_thresh=pred_iou_thresh, stability_score_thresh=stability_score_thresh, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class qr_code_controlnet(FastClient):
    """
    Generated client for zylim0702/qr-code-controlnet
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="c0eedcb3-e8ef-4107-81b8-78c7e4e92e02", api_key=api_key)
    
    def predictions(self, url: str, prompt: str, eta: float = 0.0, scheduler: str = 'DDIM', guess_mode: bool = False, num_outputs: int = 1, guidance_scale: float = 9.0, negative_prompt: str = 'Longbody, lowres, bad anatomy, bad hands, missing fingers, extra digit, fewer digits, cropped, worst quality, low quality', image_resolution: int = 768, num_inference_steps: int = 20, disable_safety_check: bool = False, qr_conditioning_scale: float = 1.0, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            url: Link Url for QR Code.
            
            prompt: Prompt for the model
            
            eta: Controls the amount of noise that is added to the input data during the denoising diffusion process. Higher value -> more noise Defaults to 0.0.
            
            scheduler: Choose a scheduler. Defaults to 'DDIM'.
            
            guess_mode: In this mode, the ControlNet encoder will try best to recognize the content of the input image even if you remove all prompts. The `guidance_scale` between 3.0 and 5.0 is recommended. Defaults to False.
            
            num_outputs: Number of images to generate Defaults to 1.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 9.0.
            
            negative_prompt: Negative prompt Defaults to 'Longbody, lowres, bad anatomy, bad hands, missing fingers, extra digit, fewer digits, cropped, worst quality, low quality'.
            
            image_resolution: Resolution of image (smallest dimension) Defaults to 768.
            
            num_inference_steps: Steps to run denoising Defaults to 20.
            
            disable_safety_check: Disable safety check. Use at your own risk! Defaults to False.
            
            qr_conditioning_scale: Conditioning scale for qr controlnet Defaults to 1.0.
            
            seed: Seed Optional.
            
        """
        return self.submit_job("/predictions", url=url, prompt=prompt, eta=eta, scheduler=scheduler, guess_mode=guess_mode, num_outputs=num_outputs, guidance_scale=guidance_scale, negative_prompt=negative_prompt, image_resolution=image_resolution, num_inference_steps=num_inference_steps, disable_safety_check=disable_safety_check, qr_conditioning_scale=qr_conditioning_scale, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class realvisxl_v3_0_turbo(FastClient):
    """
    Generated client for adirik/realvisxl-v3-0-turbo
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="0a8cebfd-16f5-444c-bfbc-f28bc61dd6fd", api_key=api_key)
    
    def predictions(self, width: int = 768, height: int = 768, prompt: str = 'An astronaut riding a rainbow unicorn', refine: str = 'no_refiner', scheduler: str = 'DPM++_SDE_Karras', num_outputs: int = 1, guidance_scale: float = 2.0, apply_watermark: bool = False, high_noise_frac: float = 0.8, negative_prompt: str = '(worst quality, low quality, illustration, 3d, 2d, painting, cartoons, sketch), open mouth', prompt_strength: float = 0.8, num_inference_steps: int = 25, disable_safety_checker: bool = False, mask: Optional[Union[MediaFile, str, bytes]] = None, seed: Optional[int] = None, image: Optional[Union[MediaFile, str, bytes]] = None, refine_steps: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            width: Width of output image Defaults to 768.
            
            height: Height of output image Defaults to 768.
            
            prompt: Input prompt Defaults to 'An astronaut riding a rainbow unicorn'.
            
            refine: Which refine style to use Defaults to 'no_refiner'.
            
            scheduler: Scheduler to use, DPM++ SDE Karras is recommended Defaults to 'DPM++_SDE_Karras'.
            
            num_outputs: Number of images to output. Defaults to 1.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 2.0.
            
            apply_watermark: Applies a watermark to enable determining if an image is generated in downstream applications. If you have other provisions for generating or deploying images safely, you can use this to disable watermarking. Defaults to False.
            
            high_noise_frac: For expert_ensemble_refiner, the fraction of noise to use Defaults to 0.8.
            
            negative_prompt: Input Negative Prompt Defaults to '(worst quality, low quality, illustration, 3d, 2d, painting, cartoons, sketch), open mouth'.
            
            prompt_strength: Prompt strength when using img2img / inpaint. 1.0 corresponds to full destruction of information in image Defaults to 0.8.
            
            num_inference_steps: Number of denoising steps Defaults to 25.
            
            disable_safety_checker: Disable safety checker for generated images. This feature is only available through the API. See [https://replicate.com/docs/how-does-replicate-work#safety](https://replicate.com/docs/how-does-replicate-work#safety) Defaults to False.
            
            mask: Input mask for inpaint mode. Black areas will be preserved, white areas will be inpainted. Optional.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
            image: Input image for img2img or inpaint mode Optional.
            
            refine_steps: For base_image_refiner, the number of steps to refine, defaults to num_inference_steps Optional.
            
        """
        return self.submit_job("/predictions", width=width, height=height, prompt=prompt, refine=refine, scheduler=scheduler, num_outputs=num_outputs, guidance_scale=guidance_scale, apply_watermark=apply_watermark, high_noise_frac=high_noise_frac, negative_prompt=negative_prompt, prompt_strength=prompt_strength, num_inference_steps=num_inference_steps, disable_safety_checker=disable_safety_checker, mask=mask, seed=seed, image=image, refine_steps=refine_steps, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


import httpx
from typing import Dict
import os


class SocaityBackendClient:
    def __init__(self):
        self.infer_backend_url = os.getenv("SOCAITY_INFER_BACKEND_URL", "https://api.socaity.ai/v1/")
        self.api_key = os.getenv("SOCAITY_API_KEY")

    def parse_api_response(self, response: httpx.Response):
        if response.status_code == 200:
            return response.json()
        else:
            print(f"API request failed with status code {response.status_code}")
            return None
        
    def update_package(self, model_id_version: Dict[str, str]) -> Dict:
        """Get comprehensive package update with all necessary information for SDK generation"""
        client = httpx.Client()
        headers = {"Authorization": f"Bearer {self.api_key}"} if self.api_key is not None else None
        try:
            response = client.post(self.infer_backend_url + "sdk/update_package", json=model_id_version, headers=headers, timeout=400)
            return self.parse_api_response(response)
        except Exception as e:
            print(f"Could not update package: {e}")
            return None
        



from fastsdk import FastClient, APISeex

class gemma_7b_it(FastClient):
    """
    Generated client for google-deepmind/gemma-7b-it
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="4e1481a8-38e9-4e57-b9f6-0be734039e23", api_key=api_key)
    
    def predictions(self, top_k: int = 50, top_p: float = 0.95, prompt: str = 'Write me a poem about Machine Learning.', temperature: float = 0.7, max_new_tokens: int = 200, min_new_tokens: int = -1, repetition_penalty: float = 1.15, **kwargs) -> APISeex:
        """
        Run a single prediction on the model
        
        
        Args:
            top_k: When decoding text, samples from the top k most likely tokens; lower to ignore less likely tokens Defaults to 50.
            
            top_p: When decoding text, samples from the top p percentage of most likely tokens; lower to ignore less likely tokens Defaults to 0.95.
            
            prompt: Prompt to send to the model. Defaults to 'Write me a poem about Machine Learning.'.
            
            temperature: Adjusts randomness of outputs, greater than 1 is random and 0 is deterministic, 0.75 is a good starting value. Defaults to 0.7.
            
            max_new_tokens: Maximum number of tokens to generate. A word is generally 2-3 tokens Defaults to 200.
            
            min_new_tokens: Minimum number of tokens to generate. To disable, set to -1. A word is generally 2-3 tokens. Defaults to -1.
            
            repetition_penalty: A parameter that controls how repetitive text can be. Lower means more repetitive, while higher means less repetitive. Set to 1.0 to disable. Defaults to 1.15.
            
        """
        return self.submit_job("/predictions", top_k=top_k, top_p=top_p, prompt=prompt, temperature=temperature, max_new_tokens=max_new_tokens, min_new_tokens=min_new_tokens, repetition_penalty=repetition_penalty, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class blip_2(FastClient):
    """
    Generated client for andreasjansson/blip-2
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="184bb954-b6c9-4543-81f0-c455411aaad5", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], caption: bool = False, question: str = 'What is this a picture of?', temperature: float = 1.0, use_nucleus_sampling: bool = False, context: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image to query or caption
            
            caption: Select if you want to generate image captions instead of asking questions Defaults to False.
            
            question: Question to ask about this image. Leave blank for captioning Defaults to 'What is this a picture of?'.
            
            temperature: Temperature for use with nucleus sampling Defaults to 1.0.
            
            use_nucleus_sampling: Toggles the model using nucleus sampling to generate responses Defaults to False.
            
            context: Optional - previous questions and answers to be used as context for answering current question Optional.
            
        """
        return self.submit_job("/predictions", image=image, caption=caption, question=question, temperature=temperature, use_nucleus_sampling=use_nucleus_sampling, context=context, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class audio_super_resolution(FastClient):
    """
    Generated client for nateraw/audio-super-resolution
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="9e7eb7fe-4918-4151-805d-4948aa6cdc90", api_key=api_key)
    
    def predictions(self, input_file: Union[MediaFile, str, bytes], ddim_steps: int = 50, guidance_scale: float = 3.5, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            input_file: Audio to upsample
            
            ddim_steps: Number of inference steps Defaults to 50.
            
            guidance_scale: Scale for classifier free guidance Defaults to 3.5.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
        """
        return self.submit_job("/predictions", input_file=input_file, ddim_steps=ddim_steps, guidance_scale=guidance_scale, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class flux_music(FastClient):
    """
    Generated client for zsxkib/flux-music
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="dc789e86-6ab2-4f69-8406-b7754b3a6775", api_key=api_key)
    
    def predictions(self, steps: int = 50, prompt: str = 'The song is an epic blend of space-rock, rock, and post-rock genres.', model_version: str = 'base', guidance_scale: float = 7.0, negative_prompt: str = 'low quality, gentle', save_spectrogram: bool = False, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            steps: Number of sampling steps Defaults to 50.
            
            prompt: Text prompt for music generation Defaults to 'The song is an epic blend of space-rock, rock, and post-rock genres.'.
            
            model_version: Select the model version to use Defaults to 'base'.
            
            guidance_scale: Classifier-free guidance scale Defaults to 7.0.
            
            negative_prompt: Text prompt for negative guidance (unconditioned prompt) Defaults to 'low quality, gentle'.
            
            save_spectrogram: Whether to save the spectrogram image Defaults to False.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
        """
        return self.submit_job("/predictions", steps=steps, prompt=prompt, model_version=model_version, guidance_scale=guidance_scale, negative_prompt=negative_prompt, save_spectrogram=save_spectrogram, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class f5_tts(FastClient):
    """
    Generated client for x-lance/f5-tts
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="f3527621-8d19-4a30-a15a-f231a3b394f4", api_key=api_key)
    
    def predictions(self, gen_text: str, ref_audio: Union[MediaFile, str, bytes], speed: float = 1.0, remove_silence: bool = True, custom_split_words: str = '', ref_text: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            gen_text: Text to Generate
            
            ref_audio: Reference audio for voice cloning
            
            speed: Speed of the generated audio Defaults to 1.0.
            
            remove_silence: Automatically remove silences? Defaults to True.
            
            custom_split_words: Custom split words, comma separated Defaults to ''.
            
            ref_text: Reference Text Optional.
            
        """
        return self.submit_job("/predictions", gen_text=gen_text, ref_audio=ref_audio, speed=speed, remove_silence=remove_silence, custom_split_words=custom_split_words, ref_text=ref_text, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.yorickvp.llava_13b import llava_13b
from socaity.sdk.replicate.yorickvp.llava_v1_6_mistral_7b import llava_v1_6_mistral_7b
from socaity.sdk.replicate.yorickvp.llava_v1_6_vicuna_13b import llava_v1_6_vicuna_13b


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class controlnet_1_1_x_realistic_vision_v2_0(FastClient):
    """
    Generated client for usamaehsan/controlnet-1-1-x-realistic-vision-v2-0
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="0db6a1a4-eef9-44e2-b340-de3d3e96123d", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], steps: int = 20, prompt: str = '(a tabby cat)+++, high resolution, sitting on a park bench', strength: float = 0.8, max_width: float = 612.0, max_height: float = 612.0, guidance_scale: int = 10, negative_prompt: str = '(deformed iris, deformed pupils, semi-realistic, cgi, 3d, render, sketch, cartoon, drawing, anime:1.4), text, close up, cropped, out of frame, worst quality, low quality, jpeg artifacts, ugly, duplicate, morbid, mutilated, extra fingers, mutated hands, poorly drawn hands, poorly drawn face, mutation, deformed, blurry, dehydrated, bad anatomy, bad proportions, extra limbs, cloned face, disfigured, gross proportions, malformed limbs, missing arms, missing legs, extra arms, extra legs, fused fingers, too many fingers, long neck', seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image
            
            steps:  num_inference_steps Defaults to 20.
            
            prompt: prompt Defaults to '(a tabby cat)+++, high resolution, sitting on a park bench'.
            
            strength: control strength/weight Defaults to 0.8.
            
            max_width: max width of mask/image Defaults to 612.0.
            
            max_height: max height of mask/image Defaults to 612.0.
            
            guidance_scale: guidance_scale Defaults to 10.
            
            negative_prompt: negative_prompt Defaults to '(deformed iris, deformed pupils, semi-realistic, cgi, 3d, render, sketch, cartoon, drawing, anime:1.4), text, close up, cropped, out of frame, worst quality, low quality, jpeg artifacts, ugly, duplicate, morbid, mutilated, extra fingers, mutated hands, poorly drawn hands, poorly drawn face, mutation, deformed, blurry, dehydrated, bad anatomy, bad proportions, extra limbs, cloned face, disfigured, gross proportions, malformed limbs, missing arms, missing legs, extra arms, extra legs, fused fingers, too many fingers, long neck'.
            
            seed: Leave blank to randomize Optional.
            
        """
        return self.submit_job("/predictions", image=image, steps=steps, prompt=prompt, strength=strength, max_width=max_width, max_height=max_height, guidance_scale=guidance_scale, negative_prompt=negative_prompt, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.roelfrenkema.fatherofdragons import fatherofdragons
from socaity.sdk.replicate.roelfrenkema.flux1_lora_aurora import flux1_lora_aurora
from socaity.sdk.replicate.roelfrenkema.flux1_lora_betty import flux1_lora_betty
from socaity.sdk.replicate.roelfrenkema.flux1_lora_watercolors import flux1_lora_watercolors


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class bge_large_en_v1_5(FastClient):
    """
    Generated client for nateraw/bge-large-en-v1-5
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="9a896975-5072-4e81-81b5-83756e6a5de1", api_key=api_key)
    
    def predictions(self, texts: str = '', batch_size: int = 32, convert_to_numpy: bool = False, normalize_embeddings: bool = True, path: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            texts: text to embed, formatted as JSON list of strings (e.g. ["hello", "world"]) Defaults to ''.
            
            batch_size: Batch size to use when processing text data. Defaults to 32.
            
            convert_to_numpy: When true, return output as npy file. By default, we return JSON Defaults to False.
            
            normalize_embeddings: Whether to normalize embeddings. Defaults to True.
            
            path: Path to file containing text as JSONL with 'text' field or valid JSON string list. Optional.
            
        """
        return self.submit_job("/predictions", texts=texts, batch_size=batch_size, convert_to_numpy=convert_to_numpy, normalize_embeddings=normalize_embeddings, path=path, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate._01_ai.yi_34b_chat import yi_34b_chat
from socaity.sdk.replicate._01_ai.yi_6b import yi_6b
from socaity.sdk.replicate._01_ai.yi_6b_chat import yi_6b_chat
from socaity.sdk.replicate._0xdeadd.flux_your_model_name import flux_your_model_name
from socaity.sdk.replicate._0xtuba.archillect_lora import archillect_lora
from socaity.sdk.replicate._10xcrazyhorse.bonkfa import bonkfa
from socaity.sdk.replicate._851_labs.background_remover import background_remover
from socaity.sdk.replicate.abyssalsoul.cyberdad import cyberdad
from socaity.sdk.replicate.adidoes.whisperx_video_transcribe import whisperx_video_transcribe
from socaity.sdk.replicate.adirik.e5_mistral_7b_instruct import e5_mistral_7b_instruct
from socaity.sdk.replicate.adirik.flux_cinestill import flux_cinestill
from socaity.sdk.replicate.adirik.flux_fantasy_architecture import flux_fantasy_architecture
from socaity.sdk.replicate.adirik.grounding_dino import grounding_dino
from socaity.sdk.replicate.adirik.imagedream import imagedream
from socaity.sdk.replicate.adirik.interior_design import interior_design
from socaity.sdk.replicate.adirik.mamba_130m import mamba_130m
from socaity.sdk.replicate.adirik.mamba_1_4b import mamba_1_4b
from socaity.sdk.replicate.adirik.mamba_2_8b import mamba_2_8b
from socaity.sdk.replicate.adirik.mamba_2_8b_slimpj import mamba_2_8b_slimpj
from socaity.sdk.replicate.adirik.mamba_370m import mamba_370m
from socaity.sdk.replicate.adirik.mamba_790m import mamba_790m
from socaity.sdk.replicate.adirik.mvdream import mvdream
from socaity.sdk.replicate.adirik.owlvit_base_patch32 import owlvit_base_patch32
from socaity.sdk.replicate.adirik.realvisxl_v3_0_turbo import realvisxl_v3_0_turbo
from socaity.sdk.replicate.adirik.realvisxl_v4_0 import realvisxl_v4_0
from socaity.sdk.replicate.adirik.styletts2 import styletts2
from socaity.sdk.replicate.adirik.text2tex import text2tex
from socaity.sdk.replicate.adirik.texture import texture
from socaity.sdk.replicate.adirik.wonder3d import wonder3d
from socaity.sdk.replicate.advoworks.lokidog import lokidog
from socaity.sdk.replicate.afiaka87.tortoise_tts import tortoise_tts
from socaity.sdk.replicate.afterpeak.flux_slowed import flux_slowed
from socaity.sdk.replicate.agusdor.pen_lettering_flux_lora import pen_lettering_flux_lora
from socaity.sdk.replicate.ah77ac.majestyrabbit_flux_lora import majestyrabbit_flux_lora
from socaity.sdk.replicate.ahmdyassr.mask_clothing import mask_clothing
from socaity.sdk.replicate.ai_forever.kandinsky_2 import kandinsky_2
from socaity.sdk.replicate.ai_forever.kandinsky_2_1 import kandinsky_2_1
from socaity.sdk.replicate.ai_forever.kandinsky_2_2 import kandinsky_2_2
from socaity.sdk.replicate.aj1357.ai_tshirt_mockup import ai_tshirt_mockup
from socaity.sdk.replicate.aleksa_codes.flux_ghibsky_illustration import flux_ghibsky_illustration
from socaity.sdk.replicate.alekseycalvin.acsoonr_flux import acsoonr_flux
from socaity.sdk.replicate.alexvoorheesmusic.yanisse import yanisse
from socaity.sdk.replicate.ali_vilab.i2vgen_xl import i2vgen_xl
from socaity.sdk.replicate.allenhung1025.looptest import looptest
from socaity.sdk.replicate.allthingsai69.sydneysweeney import sydneysweeney
from socaity.sdk.replicate.andreasjansson.blip_2 import blip_2
from socaity.sdk.replicate.andreasjansson.cantable_diffuguesion import cantable_diffuguesion
from socaity.sdk.replicate.andreasjansson.clip_features import clip_features
from socaity.sdk.replicate.andreasjansson.flux_goo import flux_goo
from socaity.sdk.replicate.andreasjansson.flux_me import flux_me
from socaity.sdk.replicate.andreasjansson.flux_shapes import flux_shapes
from socaity.sdk.replicate.andreasjansson.illusion import illusion
from socaity.sdk.replicate.andreasjansson.llama_2_13b_embeddings import llama_2_13b_embeddings
from socaity.sdk.replicate.andreasjansson.music_inpainting_bert import music_inpainting_bert
from socaity.sdk.replicate.andreasjansson.musicgen_looper import musicgen_looper
from socaity.sdk.replicate.andreasjansson.stable_diffusion_animation import stable_diffusion_animation
from socaity.sdk.replicate.andreasjansson.tile_morph import tile_morph
from socaity.sdk.replicate.andreasjansson.wan_1_3b_inpaint import wan_1_3b_inpaint
from socaity.sdk.replicate.annahung31.emopia import emopia
from socaity.sdk.replicate.anotherjesse.zeroscope_v2_xl import zeroscope_v2_xl
from socaity.sdk.replicate.aperture_2.hido import hido
from socaity.sdk.replicate.apolinario.flux_tarot_v1 import flux_tarot_v1
from socaity.sdk.replicate.aramintak.enna_sketch_style import enna_sketch_style
from socaity.sdk.replicate.aramintak.flux_film_foto import flux_film_foto
from socaity.sdk.replicate.aramintak.flux_frosting_lane import flux_frosting_lane
from socaity.sdk.replicate.aramintak.flux_koda import flux_koda
from socaity.sdk.replicate.aramintak.flux_softserve_anime import flux_softserve_anime
from socaity.sdk.replicate.aramintak.linnea_flux_beta import linnea_flux_beta
from socaity.sdk.replicate.aramintak.mooniverse import mooniverse
from socaity.sdk.replicate.arcanite24.animation2k_flux import animation2k_flux
from socaity.sdk.replicate.arielreplicate.deoldify_video import deoldify_video
from socaity.sdk.replicate.arielreplicate.robust_video_matting import robust_video_matting
from socaity.sdk.replicate.arielreplicate.stable_diffusion_infinite_zoom import stable_diffusion_infinite_zoom
from socaity.sdk.replicate.astronautdavid1.mad2_flux_lora import mad2_flux_lora
from socaity.sdk.replicate.awerks.neon_tts import neon_tts
from socaity.sdk.replicate.banta2000.mytestmodel import mytestmodel
from socaity.sdk.replicate.beautyyuyanli.multilingual_e5_large import multilingual_e5_large
from socaity.sdk.replicate.benj_edwards.dads_uppercase_2500_steps import dads_uppercase_2500_steps
from socaity.sdk.replicate.bingbangboom_lab.flux_dreamscape import flux_dreamscape
from socaity.sdk.replicate.black_forest_labs.flux_schnell import flux_schnell
from socaity.sdk.replicate.bonapartee.thumbnail_generator import thumbnail_generator
from socaity.sdk.replicate.brunnolou.flux_texture_abstract_painting import flux_texture_abstract_painting
from socaity.sdk.replicate.buildingwithai.ai_jo import ai_jo
from socaity.sdk.replicate.bytedance.hyper_flux_16step import hyper_flux_16step
from socaity.sdk.replicate.bytedance.hyper_flux_8step import hyper_flux_8step
from socaity.sdk.replicate.bytedance.sdxl_lightning_4step import sdxl_lightning_4step
from socaity.sdk.replicate.camenduru.lgm import lgm
from socaity.sdk.replicate.camenduru.lgm_ply_to_glb import lgm_ply_to_glb
from socaity.sdk.replicate.camenduru.metavoice import metavoice
from socaity.sdk.replicate.camenduru.tripo_sr import tripo_sr
from socaity.sdk.replicate.carlosperz88.teslacyberbeast import teslacyberbeast
from socaity.sdk.replicate.cddietz.michael import michael
from socaity.sdk.replicate.cdreier.golang_gopher_flux import golang_gopher_flux
from socaity.sdk.replicate.center_for_curriculum_redesign.bge_1_5_query_embeddings import bge_1_5_query_embeddings
from socaity.sdk.replicate.charlesmccarthy.addwatermark import addwatermark
from socaity.sdk.replicate.chatworks.luchtpods import luchtpods
from socaity.sdk.replicate.chenxwh.cogvlm2_video import cogvlm2_video
from socaity.sdk.replicate.chigozienri.image_urls_to_video import image_urls_to_video
from socaity.sdk.replicate.chigozienri.mediapipe_face import mediapipe_face
from socaity.sdk.replicate.cjwbw.controlvideo import controlvideo
from socaity.sdk.replicate.cjwbw.damo_text_to_video import damo_text_to_video
from socaity.sdk.replicate.cjwbw.parler_tts import parler_tts
from socaity.sdk.replicate.cjwbw.rembg import rembg
from socaity.sdk.replicate.cjwbw.rudalle_sr import rudalle_sr
from socaity.sdk.replicate.cjwbw.seamless_communication import seamless_communication
from socaity.sdk.replicate.cjwbw.semantic_segment_anything import semantic_segment_anything
from socaity.sdk.replicate.cjwbw.shap_e import shap_e
from socaity.sdk.replicate.cjwbw.supir import supir
from socaity.sdk.replicate.cjwbw.text2video_zero import text2video_zero
from socaity.sdk.replicate.cjwbw.videocrafter import videocrafter
from socaity.sdk.replicate.cjwbw.voicecraft import voicecraft
from socaity.sdk.replicate.ckizer.ckizer_64 import ckizer_64
from socaity.sdk.replicate.codingfu.bayc import bayc
from socaity.sdk.replicate.cristobalascencio.florentino import florentino
from socaity.sdk.replicate.cristobalascencio.wirra import wirra
from socaity.sdk.replicate.cswry.seesr import seesr
from socaity.sdk.replicate.ctrimm.backyard_sports_character_creator import backyard_sports_character_creator
from socaity.sdk.replicate.cuuupid.cogvideox_5b import cogvideox_5b
from socaity.sdk.replicate.cuuupid.flux_lineart import flux_lineart
from socaity.sdk.replicate.cuuupid.gte_qwen2_7b_instruct import gte_qwen2_7b_instruct
from socaity.sdk.replicate.daanelson.imagebind import imagebind
from socaity.sdk.replicate.daanelson.whisperx import whisperx
from socaity.sdk.replicate.daanelson.yolox import yolox
from socaity.sdk.replicate.darionaviar.cinthia import cinthia
from socaity.sdk.replicate.darionaviar.dario_naviar import dario_naviar
from socaity.sdk.replicate.datacte.flux_aesthetic_anime import flux_aesthetic_anime
from socaity.sdk.replicate.datacte.flux_synthetic_anime import flux_synthetic_anime
from socaity.sdk.replicate.datacte.proteus_v0_2 import proteus_v0_2
from socaity.sdk.replicate.datacte.proteus_v0_3 import proteus_v0_3
from socaity.sdk.replicate.davidkwcheng.jessicayu02 import jessicayu02
from socaity.sdk.replicate.davisbrown.flux_half_illustration import flux_half_illustration
from socaity.sdk.replicate.davisbrown.photo_glow import photo_glow
from socaity.sdk.replicate.dcamsdev.klm_lora_flux import klm_lora_flux
from socaity.sdk.replicate.declare_lab.mustango import mustango
from socaity.sdk.replicate.deepfates.deepfits_flux_dev import deepfits_flux_dev
from socaity.sdk.replicate.deepfates.flux_hot_zuck import flux_hot_zuck
from socaity.sdk.replicate.deepseek_ai.deepseek_r1 import deepseek_r1
from socaity.sdk.replicate.deepseek_ai.deepseek_v3 import deepseek_v3
from socaity.sdk.replicate.deforum.deforum_stable_diffusion import deforum_stable_diffusion
from socaity.sdk.replicate.derrrick.flux_70s_bands import flux_70s_bands
from socaity.sdk.replicate.dfrostar.hermes_kellybag import hermes_kellybag
from socaity.sdk.replicate.digitaljohn.urban_narrative import urban_narrative
from socaity.sdk.replicate.dunaevai135.tst2_d import tst2_d
from socaity.sdk.replicate.dunaevai135.tst_svt3 import tst_svt3
from socaity.sdk.replicate.dunaevai135.tst_trn import tst_trn
from socaity.sdk.replicate.emunozhern.fluxtok import fluxtok
from socaity.sdk.replicate.enkey08.ganpatibappa import ganpatibappa
from socaity.sdk.replicate.esgfit.flux_andreas import flux_andreas
from socaity.sdk.replicate.evtn.pouyippie import pouyippie
from socaity.sdk.replicate.falcons_ai.nsfw_image_detection import nsfw_image_detection
from socaity.sdk.replicate.fanyiy.flux_notion_illustration import flux_notion_illustration
from socaity.sdk.replicate.felixyifeiwang.eom_phase1 import eom_phase1
from socaity.sdk.replicate.fermatresearch.dpo_sdxl_controlnet_lora import dpo_sdxl_controlnet_lora
from socaity.sdk.replicate.fermatresearch.high_resolution_controlnet_tile import high_resolution_controlnet_tile
from socaity.sdk.replicate.fermatresearch.magic_image_refiner import magic_image_refiner
from socaity.sdk.replicate.fermatresearch.sdxl_controlnet_lora import sdxl_controlnet_lora
from socaity.sdk.replicate.fermatresearch.spanish_f5_tts import spanish_f5_tts
from socaity.sdk.replicate.ferunelli.chadmeme import chadmeme
from socaity.sdk.replicate.fesilva196.lipex import lipex
from socaity.sdk.replicate.fewjative.ultimate_sd_upscale import ultimate_sd_upscale
from socaity.sdk.replicate.fictions_ai.autocaption import autocaption
from socaity.sdk.replicate.firtoz.trellis import trellis
from socaity.sdk.replicate.fofr._0_1_webp import _0_1_webp
from socaity.sdk.replicate.fofr.any_comfyui_workflow import any_comfyui_workflow
from socaity.sdk.replicate.fofr.audio_to_waveform import audio_to_waveform
from socaity.sdk.replicate.fofr.aura_flow import aura_flow
from socaity.sdk.replicate.fofr.controlnet_preprocessors import controlnet_preprocessors
from socaity.sdk.replicate.fofr.flux_2004 import flux_2004
from socaity.sdk.replicate.fofr.flux_80s_cyberpunk import flux_80s_cyberpunk
from socaity.sdk.replicate.fofr.flux_bad_70s_food import flux_bad_70s_food
from socaity.sdk.replicate.fofr.flux_beyond_horizon import flux_beyond_horizon
from socaity.sdk.replicate.fofr.flux_black_light import flux_black_light
from socaity.sdk.replicate.fofr.flux_brighton_west_pier import flux_brighton_west_pier
from socaity.sdk.replicate.fofr.flux_cassette_futurism import flux_cassette_futurism
from socaity.sdk.replicate.fofr.flux_color import flux_color
from socaity.sdk.replicate.fofr.flux_cross_section import flux_cross_section
from socaity.sdk.replicate.fofr.flux_cyberpunk_typeface import flux_cyberpunk_typeface
from socaity.sdk.replicate.fofr.flux_hyundai_n_vision_74 import flux_hyundai_n_vision_74
from socaity.sdk.replicate.fofr.flux_jwst import flux_jwst
from socaity.sdk.replicate.fofr.flux_macro_texture import flux_macro_texture
from socaity.sdk.replicate.fofr.flux_minecraft_movie import flux_minecraft_movie
from socaity.sdk.replicate.fofr.flux_mjv3 import flux_mjv3
from socaity.sdk.replicate.fofr.flux_mona_lisa import flux_mona_lisa
from socaity.sdk.replicate.fofr.flux_myst import flux_myst
from socaity.sdk.replicate.fofr.flux_neo_1x import flux_neo_1x
from socaity.sdk.replicate.fofr.flux_pixar_cars import flux_pixar_cars
from socaity.sdk.replicate.fofr.flux_spitting_image import flux_spitting_image
from socaity.sdk.replicate.fofr.flux_tessellate import flux_tessellate
from socaity.sdk.replicate.fofr.flux_wrong import flux_wrong
from socaity.sdk.replicate.fofr.flux_y2k import flux_y2k
from socaity.sdk.replicate.fofr.frames_to_video import frames_to_video
from socaity.sdk.replicate.fofr.latent_consistency_model import latent_consistency_model
from socaity.sdk.replicate.fofr.musicgen_choral import musicgen_choral
from socaity.sdk.replicate.fofr.realvisxl_v3_multi_controlnet_lora import realvisxl_v3_multi_controlnet_lora
from socaity.sdk.replicate.fofr.sdxl_emoji import sdxl_emoji
from socaity.sdk.replicate.fofr.sdxl_multi_controlnet_lora import sdxl_multi_controlnet_lora
from socaity.sdk.replicate.fofr.sticker_maker import sticker_maker
from socaity.sdk.replicate.fofr.toolkit import toolkit
from socaity.sdk.replicate.fofr.tooncrafter import tooncrafter
from socaity.sdk.replicate.fofr.video_morpher import video_morpher
from socaity.sdk.replicate.fofr.video_to_frames import video_to_frames
from socaity.sdk.replicate.fofr.wan2_1_with_lora import wan2_1_with_lora
from socaity.sdk.replicate.gajendrajha09.fluxloramimi import fluxloramimi
from socaity.sdk.replicate.galverse.mama_flux_v1 import mama_flux_v1
from socaity.sdk.replicate.genericdeag.comic_style import comic_style
from socaity.sdk.replicate.genmoai.mochi_1 import mochi_1
from socaity.sdk.replicate.geobotsar81.geobotsar_flux_2 import geobotsar_flux_2
from socaity.sdk.replicate.google_deepmind.gemma_2b import gemma_2b
from socaity.sdk.replicate.google_deepmind.gemma_2b_it import gemma_2b_it
from socaity.sdk.replicate.google_deepmind.gemma_7b import gemma_7b
from socaity.sdk.replicate.google_deepmind.gemma_7b_it import gemma_7b_it
from socaity.sdk.replicate.hadilq.hair_segment import hair_segment
from socaity.sdk.replicate.halimalrasihi.flux_mystic_animals import flux_mystic_animals
from socaity.sdk.replicate.halimalrasihi.flux_red_cinema import flux_red_cinema
from socaity.sdk.replicate.haoheliu.audio_ldm import audio_ldm
from socaity.sdk.replicate.harmonai.dance_diffusion import dance_diffusion
from socaity.sdk.replicate.hartmamt.flux_chicago_firesidebowl import flux_chicago_firesidebowl
from socaity.sdk.replicate.hassamdevsy.mask2former import mask2former
from socaity.sdk.replicate.idea_research.ram_grounded_sam import ram_grounded_sam
from socaity.sdk.replicate.idvorkin.idvorkin_flux_lora_1 import idvorkin_flux_lora_1
from socaity.sdk.replicate.igorriti.flux_360 import flux_360
from socaity.sdk.replicate.igorriti.flux_fileteado import flux_fileteado
from socaity.sdk.replicate.ihor_thecoach.ihor2 import ihor2
from socaity.sdk.replicate.ismail_seleit.formfinder_flux import formfinder_flux
from socaity.sdk.replicate.jaaari.kokoro_82m import kokoro_82m
from socaity.sdk.replicate.jagilley.controlnet_canny import controlnet_canny
from socaity.sdk.replicate.jagilley.controlnet_depth2img import controlnet_depth2img
from socaity.sdk.replicate.jagilley.controlnet_hed import controlnet_hed
from socaity.sdk.replicate.jagilley.controlnet_hough import controlnet_hough
from socaity.sdk.replicate.jagilley.controlnet_normal import controlnet_normal
from socaity.sdk.replicate.jagilley.controlnet_pose import controlnet_pose
from socaity.sdk.replicate.jagilley.controlnet_scribble import controlnet_scribble
from socaity.sdk.replicate.jagilley.controlnet_seg import controlnet_seg
from socaity.sdk.replicate.jakedahn.flux_latentpop import flux_latentpop
from socaity.sdk.replicate.jakedahn.flux_soviet_controlrooms import flux_soviet_controlrooms
from socaity.sdk.replicate.jamorphy.moebius_flux_lora import moebius_flux_lora
from socaity.sdk.replicate.jan890.flux_dev_ascii_art import flux_dev_ascii_art
from socaity.sdk.replicate.janghaludu.kocchaga import kocchaga
from socaity.sdk.replicate.jarvis_labs2024.console_cowboy_flux import console_cowboy_flux
from socaity.sdk.replicate.jarvis_labs2024.flux_appleseed import flux_appleseed
from socaity.sdk.replicate.jarvis_labs2024.flux_raylene import flux_raylene
from socaity.sdk.replicate.jayenkai.derek import derek
from socaity.sdk.replicate.jbilcke.flux_dev_panorama_lora import flux_dev_panorama_lora
from socaity.sdk.replicate.jcbianchi010.jeancbianchi import jeancbianchi
from socaity.sdk.replicate.jd7h.edit_video_by_editing_text import edit_video_by_editing_text
from socaity.sdk.replicate.jd7h.zero123plusplus import zero123plusplus
from socaity.sdk.replicate.jfobrien29.flux_us_national_parks import flux_us_national_parks
from socaity.sdk.replicate.jiht76.mindyflux import mindyflux
from socaity.sdk.replicate.jingyunliang.hcflow_sr import hcflow_sr
from socaity.sdk.replicate.jingyunliang.swinir import swinir
from socaity.sdk.replicate.joshelgar.rssmurryflux import rssmurryflux
from socaity.sdk.replicate.juergengunz.ultimate_portrait_upscale import ultimate_portrait_upscale
from socaity.sdk.replicate.juliananev.frutiger_aero import frutiger_aero
from socaity.sdk.replicate.julienhypeer.julienetoke import julienetoke
from socaity.sdk.replicate.justmalhar.flux_mobile_ui import flux_mobile_ui
from socaity.sdk.replicate.justmalhar.flux_sketchnotes import flux_sketchnotes
from socaity.sdk.replicate.justmalhar.flux_thumbnails import flux_thumbnails
from socaity.sdk.replicate.jweek.mask_maker import mask_maker
from socaity.sdk.replicate.karlvann.karl import karl
from socaity.sdk.replicate.kazdatahelp.llkm import llkm
from socaity.sdk.replicate.kcaverly.nous_hermes_2_yi_34b_gguf import nous_hermes_2_yi_34b_gguf
from socaity.sdk.replicate.koratkar.miyazaki_watercolor import miyazaki_watercolor
from socaity.sdk.replicate.krthr.clip_embeddings import clip_embeddings
from socaity.sdk.replicate.levelsio.analog_film import analog_film
from socaity.sdk.replicate.levelsio.brain_flakes_ai import brain_flakes_ai
from socaity.sdk.replicate.levelsio.disposable_camera import disposable_camera
from socaity.sdk.replicate.levelsio.lomography import lomography
from socaity.sdk.replicate.levelsio.neon_tokyo import neon_tokyo
from socaity.sdk.replicate.lightricks.ltx_video import ltx_video
from socaity.sdk.replicate.linoytsaban.flux_yarn_art import flux_yarn_art
from socaity.sdk.replicate.lipex157zoi.lipexbradok import lipexbradok
from socaity.sdk.replicate.lisandroe.loralisandro import loralisandro
from socaity.sdk.replicate.lucataco.ace_step import ace_step
from socaity.sdk.replicate.lucataco.controlnet_tile import controlnet_tile
from socaity.sdk.replicate.lucataco.csm_1b import csm_1b
from socaity.sdk.replicate.lucataco.deep3d import deep3d
from socaity.sdk.replicate.lucataco.demofusion_enhance import demofusion_enhance
from socaity.sdk.replicate.lucataco.depth_anything_video import depth_anything_video
from socaity.sdk.replicate.lucataco.dreamshaper_xl_turbo import dreamshaper_xl_turbo
from socaity.sdk.replicate.lucataco.florence_2_large import florence_2_large
from socaity.sdk.replicate.lucataco.flux_queso import flux_queso
from socaity.sdk.replicate.lucataco.flux_syd_mead import flux_syd_mead
from socaity.sdk.replicate.lucataco.flux_vlta import flux_vlta
from socaity.sdk.replicate.lucataco.flux_watercolor import flux_watercolor
from socaity.sdk.replicate.lucataco.frame_extractor import frame_extractor
from socaity.sdk.replicate.lucataco.hotshot_xl import hotshot_xl
from socaity.sdk.replicate.lucataco.img_and_audio2video import img_and_audio2video
from socaity.sdk.replicate.lucataco.magnet import magnet
from socaity.sdk.replicate.lucataco.merge_img import merge_img
from socaity.sdk.replicate.lucataco.mvsep_mdx23_music_separation import mvsep_mdx23_music_separation
from socaity.sdk.replicate.lucataco.nomic_embed_text_v1 import nomic_embed_text_v1
from socaity.sdk.replicate.lucataco.nsfw_video_detection import nsfw_video_detection
from socaity.sdk.replicate.lucataco.open_dalle_v1_1 import open_dalle_v1_1
from socaity.sdk.replicate.lucataco.orpheus_3b_0_1_ft import orpheus_3b_0_1_ft
from socaity.sdk.replicate.lucataco.pasd_magnify import pasd_magnify
from socaity.sdk.replicate.lucataco.pheme import pheme
from socaity.sdk.replicate.lucataco.phi_2 import phi_2
from socaity.sdk.replicate.lucataco.phixtral_2x2_8 import phixtral_2x2_8
from socaity.sdk.replicate.lucataco.pixart_xl_2 import pixart_xl_2
from socaity.sdk.replicate.lucataco.qwen1_5_72b import qwen1_5_72b
from socaity.sdk.replicate.lucataco.qwen1_5_7b import qwen1_5_7b
from socaity.sdk.replicate.lucataco.real_esrgan_video import real_esrgan_video
from socaity.sdk.replicate.lucataco.realistic_vision_v5 import realistic_vision_v5
from socaity.sdk.replicate.lucataco.realistic_vision_v5_1 import realistic_vision_v5_1
from socaity.sdk.replicate.lucataco.realvisxl2_lcm import realvisxl2_lcm
from socaity.sdk.replicate.lucataco.realvisxl_v2_0 import realvisxl_v2_0
from socaity.sdk.replicate.lucataco.rembg_video import rembg_video
from socaity.sdk.replicate.lucataco.sdxl_controlnet import sdxl_controlnet
from socaity.sdk.replicate.lucataco.singing_voice_conversion import singing_voice_conversion
from socaity.sdk.replicate.lucataco.snowflake_arctic_embed_l import snowflake_arctic_embed_l
from socaity.sdk.replicate.lucataco.ssd_1b import ssd_1b
from socaity.sdk.replicate.lucataco.stable_diffusion_x4_upscaler import stable_diffusion_x4_upscaler
from socaity.sdk.replicate.lucataco.video_merge import video_merge
from socaity.sdk.replicate.lucataco.video_split import video_split
from socaity.sdk.replicate.lucataco.wan_2_1_1_3b_vid2vid import wan_2_1_1_3b_vid2vid
from socaity.sdk.replicate.lucataco.xtts_v2 import xtts_v2
from socaity.sdk.replicate.ludocomito.flux_caravaggio import flux_caravaggio
from socaity.sdk.replicate.m1guelpf.whisper_subtitles import whisper_subtitles
from socaity.sdk.replicate.makinsongary698.jh import jh
from socaity.sdk.replicate.mandelavybe.jungkook import jungkook
from socaity.sdk.replicate.marckohlbrugge.flux_wojak_v2 import flux_wojak_v2
from socaity.sdk.replicate.marcusschwarze.paul_mittelrheintaler import paul_mittelrheintaler
from socaity.sdk.replicate.mark3labs.embeddings_gte_base import embeddings_gte_base
from socaity.sdk.replicate.markbland82.mjbstyle1 import mjbstyle1
from socaity.sdk.replicate.markredito._90sbadtrip import _90sbadtrip
from socaity.sdk.replicate.maybasmanphotographer.bmayb import bmayb
from socaity.sdk.replicate.melaesse.ginevra import ginevra
from socaity.sdk.replicate.men1scus.birefnet import birefnet
from socaity.sdk.replicate.meta.llama_4_maverick_instruct import llama_4_maverick_instruct
from socaity.sdk.replicate.meta.meta_llama_3_1_405b_instruct import meta_llama_3_1_405b_instruct
from socaity.sdk.replicate.meta.meta_llama_3_70b_instruct import meta_llama_3_70b_instruct
from socaity.sdk.replicate.meta.meta_llama_3_8b import meta_llama_3_8b
from socaity.sdk.replicate.meta.meta_llama_3_8b_instruct import meta_llama_3_8b_instruct
from socaity.sdk.replicate.meta.musicgen import musicgen
from socaity.sdk.replicate.meta.sam_2 import sam_2
from socaity.sdk.replicate.meta.sam_2_video import sam_2_video
from socaity.sdk.replicate.midllle.material_maker import material_maker
from socaity.sdk.replicate.mintkaori.seoulgi import seoulgi
from socaity.sdk.replicate.mofleck.teslasemishipped import teslasemishipped
from socaity.sdk.replicate.mv_lab.swin2sr import swin2sr
from socaity.sdk.replicate.naklecha.clothing_segmentation import clothing_segmentation
from socaity.sdk.replicate.nateraw.audio_super_resolution import audio_super_resolution
from socaity.sdk.replicate.nateraw.autotune import autotune
from socaity.sdk.replicate.nateraw.bge_large_en_v1_5 import bge_large_en_v1_5
from socaity.sdk.replicate.nateraw.musicgen_songstarter_v0_2 import musicgen_songstarter_v0_2
from socaity.sdk.replicate.nateraw.nous_hermes_2_solar_10_7b import nous_hermes_2_solar_10_7b
from socaity.sdk.replicate.nateraw.nous_hermes_llama2_awq import nous_hermes_llama2_awq
from socaity.sdk.replicate.nateraw.stable_diffusion_videos import stable_diffusion_videos
from socaity.sdk.replicate.nicknaskida.whisper_diarization import whisper_diarization
from socaity.sdk.replicate.nicolas7894.flux_undraw import flux_undraw
from socaity.sdk.replicate.nicolascoutureau.video_utils import video_utils
from socaity.sdk.replicate.nightmareai.disco_diffusion import disco_diffusion
from socaity.sdk.replicate.nightmareai.latent_sr import latent_sr
from socaity.sdk.replicate.nightmareai.real_esrgan import real_esrgan
from socaity.sdk.replicate.nvidia.parakeet_rnnt_1_1b import parakeet_rnnt_1_1b
from socaity.sdk.replicate.nvidia.sana import sana
from socaity.sdk.replicate.nvidia.sana_sprint_1_6b import sana_sprint_1_6b
from socaity.sdk.replicate.okostadsjunior.ninicollyloli import ninicollyloli
from socaity.sdk.replicate.okturan.flux_yesilcam import flux_yesilcam
from socaity.sdk.replicate.open_mmlab.pia import pia
from socaity.sdk.replicate.openai.gpt_4_1 import gpt_4_1
from socaity.sdk.replicate.openai.gpt_4_1_mini import gpt_4_1_mini
from socaity.sdk.replicate.openai.gpt_4_1_nano import gpt_4_1_nano
from socaity.sdk.replicate.openai.gpt_4o import gpt_4o
from socaity.sdk.replicate.openai.gpt_4o_mini import gpt_4o_mini
from socaity.sdk.replicate.openai.o1 import o1
from socaity.sdk.replicate.openai.o1_mini import o1_mini
from socaity.sdk.replicate.openai.whisper import whisper
from socaity.sdk.replicate.ori299.mc_thumbnails_v1 import mc_thumbnails_v1
from socaity.sdk.replicate.oshtz.flux_celpast import flux_celpast
from socaity.sdk.replicate.oshtz.flux_plastic3d import flux_plastic3d
from socaity.sdk.replicate.paulbasic.flux_paulh import flux_paulh
from socaity.sdk.replicate.pbarker.gfpgan_video import gfpgan_video
from socaity.sdk.replicate.pbuyle.banchan_flux import banchan_flux
from socaity.sdk.replicate.pellmellism.xkcd import xkcd
from socaity.sdk.replicate.philz1337x.controlnet_deliberate import controlnet_deliberate
from socaity.sdk.replicate.platform_kit.mars5_tts import mars5_tts
from socaity.sdk.replicate.playgroundai.playground_v2_5_1024px_aesthetic import playground_v2_5_1024px_aesthetic
from socaity.sdk.replicate.pnyompen.sd_controlnet_lora import sd_controlnet_lora
from socaity.sdk.replicate.pollinations.modnet import modnet
from socaity.sdk.replicate.pollinations.real_basicvsr_video_superresolution import real_basicvsr_video_superresolution
from socaity.sdk.replicate.pollinations.stable_diffusion_dance import stable_diffusion_dance
from socaity.sdk.replicate.pollinations.tune_a_video import tune_a_video
from socaity.sdk.replicate.popovluka.luka_flux_lora_model import luka_flux_lora_model
from socaity.sdk.replicate.prestoncreed.flux_spongebob import flux_spongebob
from socaity.sdk.replicate.prunaai.flux_1_dev import flux_1_dev
from socaity.sdk.replicate.prunaai.hidream_l1_dev import hidream_l1_dev
from socaity.sdk.replicate.prunaai.hidream_l1_fast import hidream_l1_fast
from socaity.sdk.replicate.prunaai.hidream_l1_full import hidream_l1_full
from socaity.sdk.replicate.prunaai.hunyuan3d_2 import hunyuan3d_2
from socaity.sdk.replicate.prunaai.sdxl_lightning import sdxl_lightning
from socaity.sdk.replicate.prunaai.vace_14b import vace_14b
from socaity.sdk.replicate.prunaai.vace_1_3b import vace_1_3b
from socaity.sdk.replicate.pseudoram.rvc_v2 import rvc_v2
from socaity.sdk.replicate.pwntus.flux_albert_einstein import flux_albert_einstein
from socaity.sdk.replicate.qunash.circassian_culture_flux_3000_steps import circassian_culture_flux_3000_steps
from socaity.sdk.replicate.qunash.iphone_camera_style import iphone_camera_style
from socaity.sdk.replicate.rainer1966_de.flux_rainer import flux_rainer
from socaity.sdk.replicate.raulduke9119.flux_realism import flux_realism
from socaity.sdk.replicate.replicate.all_mpnet_base_v2 import all_mpnet_base_v2
from socaity.sdk.replicate.replicate.flan_t5_xl import flan_t5_xl
from socaity.sdk.replicate.replicate.gpt_j_6b import gpt_j_6b
from socaity.sdk.replicate.replicate.llama_7b import llama_7b
from socaity.sdk.replicate.replicate.train_rvc_model import train_rvc_model
from socaity.sdk.replicate.riffusion.riffusion import riffusion
from socaity.sdk.replicate.roberthein.modelname_new import modelname_new
from socaity.sdk.replicate.roelfrenkema.fatherofdragons import fatherofdragons
from socaity.sdk.replicate.roelfrenkema.flux1_lora_aurora import flux1_lora_aurora
from socaity.sdk.replicate.roelfrenkema.flux1_lora_betty import flux1_lora_betty
from socaity.sdk.replicate.roelfrenkema.flux1_lora_watercolors import flux1_lora_watercolors
from socaity.sdk.replicate.s76354m.fluxfinetune import fluxfinetune
from socaity.sdk.replicate.s_clementc.manon import manon
from socaity.sdk.replicate.sakemin.musicgen_stereo_chord import musicgen_stereo_chord
from socaity.sdk.replicate.schananas.grounded_sam import grounded_sam
from socaity.sdk.replicate.scmdr.ai_graphic import ai_graphic
from socaity.sdk.replicate.sczhou.codeformer import codeformer
from socaity.sdk.replicate.sdsgitaccount.flux_gmoveus import flux_gmoveus
from socaity.sdk.replicate.sebastianbodza.flux_aquarell_watercolor_style import flux_aquarell_watercolor_style
from socaity.sdk.replicate.sebastianbodza.flux_lora_retro_linedrawing_style_v1 import flux_lora_retro_linedrawing_style_v1
from socaity.sdk.replicate.sepal.audiogen import audiogen
from socaity.sdk.replicate.sevensevenimages.rolxsub import rolxsub
from socaity.sdk.replicate.shapestudio.floating_flux import floating_flux
from socaity.sdk.replicate.shapestudio.nihon_flux import nihon_flux
from socaity.sdk.replicate.shapestudio.portra_800_flux import portra_800_flux
from socaity.sdk.replicate.shapestudio.wild_flux import wild_flux
from socaity.sdk.replicate.sigil_wen.laika_flux_lora import laika_flux_lora
from socaity.sdk.replicate.sigil_wen.pepsi_flux import pepsi_flux
from socaity.sdk.replicate.smoretalk.rembg_enhance import rembg_enhance
from socaity.sdk.replicate.someone12dd.libreintense import libreintense
from socaity.sdk.replicate.someone12dd.muskoil1 import muskoil1
from socaity.sdk.replicate.stability_ai.sdxl import sdxl
from socaity.sdk.replicate.stability_ai.stable_diffusion import stable_diffusion
from socaity.sdk.replicate.stability_ai.stable_diffusion_inpainting import stable_diffusion_inpainting
from socaity.sdk.replicate.stability_ai.stablelm_tuned_alpha_7b import stablelm_tuned_alpha_7b
from socaity.sdk.replicate.stackadoc.stable_audio_open_1_0 import stable_audio_open_1_0
from socaity.sdk.replicate.suno_ai.bark import bark
from socaity.sdk.replicate.swook.inspyrenet import inspyrenet
from socaity.sdk.replicate.sylvesteraswin.sylvester_flux_selfie import sylvester_flux_selfie
from socaity.sdk.replicate.szdavid11.kellogs_chocos import kellogs_chocos
from socaity.sdk.replicate.szdavid11.ola_scooter import ola_scooter
from socaity.sdk.replicate.tahercoolguy.video_background_remover_appender import video_background_remover_appender
from socaity.sdk.replicate.tencent.hunyuan3d_2mv import hunyuan3d_2mv
from socaity.sdk.replicate.tencent.hunyuan_video import hunyuan_video
from socaity.sdk.replicate.tencentarc.animesr import animesr
from socaity.sdk.replicate.tencentarc.gfpgan import gfpgan
from socaity.sdk.replicate.tezzarida.aram import aram
from socaity.sdk.replicate.titouv.test_model3 import test_model3
from socaity.sdk.replicate.tjrndll.flux_dev_woodcut_prints import flux_dev_woodcut_prints
from socaity.sdk.replicate.tokaito14.art import art
from socaity.sdk.replicate.tokaito14.fullbody import fullbody
from socaity.sdk.replicate.tokaito14.laura import laura
from socaity.sdk.replicate.tokaito14.portrait import portrait
from socaity.sdk.replicate.tstramer.material_diffusion import material_diffusion
from socaity.sdk.replicate.tudortotolici.newspaper_illustration import newspaper_illustration
from socaity.sdk.replicate.tylerbishopdev.retylerv2 import retylerv2
from socaity.sdk.replicate.ugleh.flux_dev_lora_dixit import flux_dev_lora_dixit
from socaity.sdk.replicate.ugleh.flux_dev_lora_painterdetective import flux_dev_lora_painterdetective
from socaity.sdk.replicate.ummtushar.pilot import pilot
from socaity.sdk.replicate.urieltac.polar_fleece import polar_fleece
from socaity.sdk.replicate.usamaehsan.controlnet_1_1_x_realistic_vision_v2_0 import controlnet_1_1_x_realistic_vision_v2_0
from socaity.sdk.replicate.usamaehsan.controlnet_x_ip_adapter_realistic_vision_v5 import controlnet_x_ip_adapter_realistic_vision_v5
from socaity.sdk.replicate.vaibhavs10.incredibly_fast_whisper import incredibly_fast_whisper
from socaity.sdk.replicate.veryvanya.flux_ps1_style import flux_ps1_style
from socaity.sdk.replicate.warf23.agrat_me import agrat_me
from socaity.sdk.replicate.warf23.ai_glasses import ai_glasses
from socaity.sdk.replicate.witzelfitz.gardenflux import gardenflux
from socaity.sdk.replicate.wowohello.fat_funjin import fat_funjin
from socaity.sdk.replicate.x_lance.f5_tts import f5_tts
from socaity.sdk.replicate.xinntao.esrgan import esrgan
from socaity.sdk.replicate.yorickvp.llava_13b import llava_13b
from socaity.sdk.replicate.yorickvp.llava_v1_6_mistral_7b import llava_v1_6_mistral_7b
from socaity.sdk.replicate.yorickvp.llava_v1_6_vicuna_13b import llava_v1_6_vicuna_13b
from socaity.sdk.replicate.yoyo_nb.thin_plate_spline_motion_model import thin_plate_spline_motion_model
from socaity.sdk.replicate.yuezheng2006.flux_lora_gyy import flux_lora_gyy
from socaity.sdk.replicate.zeke.tarot_flux import tarot_flux
from socaity.sdk.replicate.zeke.ziki_flux import ziki_flux
from socaity.sdk.replicate.zsxkib.animate_diff import animate_diff
from socaity.sdk.replicate.zsxkib.animatediff_illusions import animatediff_illusions
from socaity.sdk.replicate.zsxkib.animatediff_prompt_travel import animatediff_prompt_travel
from socaity.sdk.replicate.zsxkib.aura_sr import aura_sr
from socaity.sdk.replicate.zsxkib.aura_sr_v2 import aura_sr_v2
from socaity.sdk.replicate.zsxkib.create_rvc_dataset import create_rvc_dataset
from socaity.sdk.replicate.zsxkib.diffbir import diffbir
from socaity.sdk.replicate.zsxkib.film_frame_interpolation_for_large_motion import film_frame_interpolation_for_large_motion
from socaity.sdk.replicate.zsxkib.flux_music import flux_music
from socaity.sdk.replicate.zsxkib.hunyuan_video2video import hunyuan_video2video
from socaity.sdk.replicate.zsxkib.ic_light_background import ic_light_background
from socaity.sdk.replicate.zsxkib.jina_clip_v2 import jina_clip_v2
from socaity.sdk.replicate.zsxkib.mimic_motion import mimic_motion
from socaity.sdk.replicate.zsxkib.mmaudio import mmaudio
from socaity.sdk.replicate.zsxkib.pyramid_flow import pyramid_flow
from socaity.sdk.replicate.zsxkib.realistic_voice_cloning import realistic_voice_cloning
from socaity.sdk.replicate.zsxkib.samurai import samurai
from socaity.sdk.replicate.zsxkib.stable_video_face_restoration import stable_video_face_restoration
from socaity.sdk.replicate.zsxkib.yolo_world import yolo_world
from socaity.sdk.replicate.zsyoaoa.invsr import invsr
from socaity.sdk.replicate.zylim0702.qr_code_controlnet import qr_code_controlnet
from socaity.sdk.replicate.zylim0702.remove_bg import remove_bg
from socaity.sdk.replicate.zzyjay.icedevsfm import icedevsfm


from fastsdk import FastClient, APISeex
from typing import Optional


class all_mpnet_base_v2(FastClient):
    """
    Generated client for replicate/all-mpnet-base-v2
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="7dd22be5-46d1-45cb-b217-e0d691806529", api_key=api_key)
    
    def predictions(self, text: Optional[str] = None, text_batch: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            text: A single string to encode. Optional.
            
            text_batch: A JSON-formatted list of strings to encode. Optional.
            
        """
        return self.submit_job("/predictions", text=text, text_batch=text_batch, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class cogvlm2_video(FastClient):
    """
    Generated client for chenxwh/cogvlm2-video
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="0290b9cc-95b5-4a7d-85ac-fecc261777e6", api_key=api_key)
    
    def predictions(self, input_video: Union[MediaFile, str, bytes], top_p: float = 0.1, prompt: str = 'Describe this video.', temperature: float = 0.1, max_new_tokens: int = 2048, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            input_video: Input video
            
            top_p: When decoding text, samples from the top p percentage of most likely tokens; lower to ignore less likely tokens Defaults to 0.1.
            
            prompt: Input prompt Defaults to 'Describe this video.'.
            
            temperature: Adjusts randomness of outputs, greater than 1 is random and 0 is deterministic Defaults to 0.1.
            
            max_new_tokens: Maximum number of tokens to generate. A word is generally 2-3 tokens Defaults to 2048.
            
        """
        return self.submit_job("/predictions", input_video=input_video, top_p=top_p, prompt=prompt, temperature=temperature, max_new_tokens=max_new_tokens, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class frame_extractor(FastClient):
    """
    Generated client for lucataco/frame-extractor
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="75d0bd49-1736-4298-b105-7d3663c3b71a", api_key=api_key)
    
    def predictions(self, video: Union[MediaFile, str, bytes], return_first_frame: bool = False, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            video: Input video file
            
            return_first_frame: Toggle to return the first frame instead of the last frame Defaults to False.
            
        """
        return self.submit_job("/predictions", video=video, return_first_frame=return_first_frame, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class illusion(FastClient):
    """
    Generated client for andreasjansson/illusion
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="972ee562-9885-4195-a023-39b551715c6f", api_key=api_key)
    
    def predictions(self, prompt: str, qr_code_content: str, seed: int = -1, width: int = 768, border: int = 1, height: int = 768, num_outputs: int = 1, guidance_scale: float = 7.5, negative_prompt: str = 'ugly, disfigured, low quality, blurry, nsfw', qrcode_background: str = 'gray', num_inference_steps: int = 40, controlnet_conditioning_scale: float = 2.2, image: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: The prompt to guide QR Code generation.
            
            qr_code_content: The website/content your QR Code will point to.
            
            seed: Seed Defaults to -1.
            
            width: Width out the output image Defaults to 768.
            
            border: QR code border size Defaults to 1.
            
            height: Height out the output image Defaults to 768.
            
            num_outputs: Number of outputs Defaults to 1.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 7.5.
            
            negative_prompt: The negative prompt to guide image generation. Defaults to 'ugly, disfigured, low quality, blurry, nsfw'.
            
            qrcode_background: Background color of raw QR code Defaults to 'gray'.
            
            num_inference_steps: Number of diffusion steps Defaults to 40.
            
            controlnet_conditioning_scale: The outputs of the controlnet are multiplied by `controlnet_conditioning_scale` before they are added to the residual in the original unet. Defaults to 2.2.
            
            image: Input image. If none is provided, a QR code will be generated Optional.
            
        """
        return self.submit_job("/predictions", prompt=prompt, qr_code_content=qr_code_content, seed=seed, width=width, border=border, height=height, num_outputs=num_outputs, guidance_scale=guidance_scale, negative_prompt=negative_prompt, qrcode_background=qrcode_background, num_inference_steps=num_inference_steps, controlnet_conditioning_scale=controlnet_conditioning_scale, image=image, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class audio_to_waveform(FastClient):
    """
    Generated client for fofr/audio-to-waveform
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="60f4f983-b431-4032-b387-28a93edb15e1", api_key=api_key)
    
    def predictions(self, audio: Union[MediaFile, str, bytes], bg_color: str = '#000000', fg_alpha: float = 0.75, bar_count: int = 100, bar_width: float = 0.4, bars_color: str = '#ffffff', caption_text: str = '', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            audio: Audio file to create waveform from
            
            bg_color: Background color of waveform Defaults to '#000000'.
            
            fg_alpha: Opacity of foreground waveform Defaults to 0.75.
            
            bar_count: Number of bars in waveform Defaults to 100.
            
            bar_width: Width of bars in waveform. 1 represents full width, 0.5 represents half width, etc. Defaults to 0.4.
            
            bars_color: Color of waveform bars Defaults to '#ffffff'.
            
            caption_text: Caption text for the video Defaults to ''.
            
        """
        return self.submit_job("/predictions", audio=audio, bg_color=bg_color, fg_alpha=fg_alpha, bar_count=bar_count, bar_width=bar_width, bars_color=bars_color, caption_text=caption_text, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class tune_a_video(FastClient):
    """
    Generated client for pollinations/tune-a-video
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="1305d4fb-b4bb-45e5-b411-2202373a9b54", api_key=api_key)
    
    def predictions(self, steps: int = 300, width: int = 512, height: int = 512, length: int = 5, source_prompt: str = 'a man surfing', target_prompts: str = 'a panda surfing\na cartoon sloth surfing', sample_frame_rate: int = 1, video: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        Run a single prediction on the model
        
        
        Args:
            steps: number of steps to train for Defaults to 300.
            
            width: width of the output video (multiples of 32) Defaults to 512.
            
            height: height of the output video (multiples of 32) Defaults to 512.
            
            length: length of the output video (in seconds) Defaults to 5.
            
            source_prompt: prompts describing the original video Defaults to 'a man surfing'.
            
            target_prompts: prompts to change the video to Defaults to 'a panda surfing\na cartoon sloth surfing'.
            
            sample_frame_rate: with which rate to sample the input video Defaults to 1.
            
            video: input video Optional.
            
        """
        return self.submit_job("/predictions", steps=steps, width=width, height=height, length=length, source_prompt=source_prompt, target_prompts=target_prompts, sample_frame_rate=sample_frame_rate, video=video, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class stable_diffusion_animation(FastClient):
    """
    Generated client for andreasjansson/stable-diffusion-animation
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="1400c39d-e851-4ec4-82fc-315ac1bf7161", api_key=api_key)
    
    def predictions(self, prompt_end: str, prompt_start: str, width: int = 512, height: int = 512, gif_ping_pong: bool = False, output_format: str = 'gif', guidance_scale: float = 7.5, prompt_strength: float = 0.8, film_interpolation: bool = True, intermediate_output: bool = False, num_inference_steps: int = 50, num_animation_frames: int = 10, gif_frames_per_second: int = 20, num_interpolation_steps: int = 5, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt_end: Prompt to end the animation with. You can include multiple prompts by separating the prompts with | (the 'pipe' character)
            
            prompt_start: Prompt to start the animation with
            
            width: Width of output image Defaults to 512.
            
            height: Height of output image Defaults to 512.
            
            gif_ping_pong: Whether to reverse the animation and go back to the beginning before looping Defaults to False.
            
            output_format: Output file format Defaults to 'gif'.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 7.5.
            
            prompt_strength: Lower prompt strength generates more coherent gifs, higher respects prompts more but can be jumpy Defaults to 0.8.
            
            film_interpolation: Whether to use FILM for between-frame interpolation (film-net.github.io) Defaults to True.
            
            intermediate_output: Whether to display intermediate outputs during generation Defaults to False.
            
            num_inference_steps: Number of denoising steps Defaults to 50.
            
            num_animation_frames: Number of frames to animate Defaults to 10.
            
            gif_frames_per_second: Frames/second in output GIF Defaults to 20.
            
            num_interpolation_steps: Number of steps to interpolate between animation frames Defaults to 5.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
        """
        return self.submit_job("/predictions", prompt_end=prompt_end, prompt_start=prompt_start, width=width, height=height, gif_ping_pong=gif_ping_pong, output_format=output_format, guidance_scale=guidance_scale, prompt_strength=prompt_strength, film_interpolation=film_interpolation, intermediate_output=intermediate_output, num_inference_steps=num_inference_steps, num_animation_frames=num_animation_frames, gif_frames_per_second=gif_frames_per_second, num_interpolation_steps=num_interpolation_steps, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class mmaudio(FastClient):
    """
    Generated client for zsxkib/mmaudio
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="b3329e4f-e7a9-4e66-830b-0f1d14d133c1", api_key=api_key)
    
    def predictions(self, prompt: str = '', duration: float = 8.0, num_steps: int = 25, cfg_strength: float = 4.5, negative_prompt: str = 'music', seed: Optional[int] = None, image: Optional[Union[MediaFile, str, bytes]] = None, video: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Text prompt for generated audio Defaults to ''.
            
            duration: Duration of output in seconds Defaults to 8.0.
            
            num_steps: Number of inference steps Defaults to 25.
            
            cfg_strength: Guidance strength (CFG) Defaults to 4.5.
            
            negative_prompt: Negative prompt to avoid certain sounds Defaults to 'music'.
            
            seed: Random seed. Use -1 or leave blank to randomize the seed Optional.
            
            image: Optional image file for image-to-audio generation (experimental) Optional.
            
            video: Optional video file for video-to-audio generation Optional.
            
        """
        return self.submit_job("/predictions", prompt=prompt, duration=duration, num_steps=num_steps, cfg_strength=cfg_strength, negative_prompt=negative_prompt, seed=seed, image=image, video=video, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class samurai(FastClient):
    """
    Generated client for zsxkib/samurai
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="0a6c1511-3558-4796-bc3c-94417a13b5a7", api_key=api_key)
    
    def predictions(self, video: Union[MediaFile, str, bytes], width: int = 400, height: int = 300, x_coordinate: int = 100, y_coordinate: int = 100, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            video: Input video to process
            
            width: Width of bounding box Defaults to 400.
            
            height: Height of bounding box Defaults to 300.
            
            x_coordinate: x-coordinate of top-left corner of bounding box Defaults to 100.
            
            y_coordinate: y-coordinate of top-left corner of bounding box Defaults to 100.
            
        """
        return self.submit_job("/predictions", video=video, width=width, height=height, x_coordinate=x_coordinate, y_coordinate=y_coordinate, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class create_rvc_dataset(FastClient):
    """
    Generated client for zsxkib/create-rvc-dataset
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="b4229eae-1f48-4adb-bcaf-502aaf304c25", api_key=api_key)
    
    def predictions(self, youtube_url: str, audio_name: str = 'rvc_v2_voices', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            youtube_url: URL to YouTube video you'd like to create your RVC v2 dataset from
            
            audio_name: Name of the dataset. The output will be a zip file containing a folder named `dataset/<audio_name>/`. This folder will include multiple `.mp3` files named as `split_<i>.mp3`. Each `split_<i>.mp3` file is a short audio clip extracted from the provided YouTube video, where voice has been isolated from the background noise. Defaults to 'rvc_v2_voices'.
            
        """
        return self.submit_job("/predictions", youtube_url=youtube_url, audio_name=audio_name, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.jarvis_labs2024.console_cowboy_flux import console_cowboy_flux
from socaity.sdk.replicate.jarvis_labs2024.flux_appleseed import flux_appleseed
from socaity.sdk.replicate.jarvis_labs2024.flux_raylene import flux_raylene


from fastsdk import FastClient, APISeex
from typing import Optional


class aura_flow(FastClient):
    """
    Generated client for fofr/aura-flow
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="926108a6-1ec1-4733-958c-a9f3a9bd63a1", api_key=api_key)
    
    def predictions(self, cfg: float = 3.5, shift: float = 1.73, steps: int = 25, width: int = 1024, height: int = 1024, prompt: str = '', sampler: str = 'uni_pc', scheduler: str = 'normal', output_format: str = 'webp', output_quality: int = 80, negative_prompt: str = '', number_of_images: int = 1, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        Run a single prediction on the model
        
        
        Args:
            cfg: The guidance scale tells the model how similar the output should be to the prompt. Defaults to 3.5.
            
            shift: The timestep scheduling shift; shift values higher than 1.0 are better at managing noise in higher resolutions. Defaults to 1.73.
            
            steps: The number of steps to run the model for (more steps = better image but slower generation. Best results for this model are around 25 steps.) Defaults to 25.
            
            width: The width of the image Defaults to 1024.
            
            height: The height of the image Defaults to 1024.
            
            prompt: prompt Defaults to ''.
            
            sampler: sampler Defaults to 'uni_pc'.
            
            scheduler: scheduler Defaults to 'normal'.
            
            output_format: Format of the output images Defaults to 'webp'.
            
            output_quality: Quality of the output images, from 0 to 100. 100 is best quality, 0 is lowest quality. Defaults to 80.
            
            negative_prompt: Things you do not want to see in your image Defaults to ''.
            
            number_of_images: The number of images to generate Defaults to 1.
            
            seed: Set a seed for reproducibility. Random by default. Optional.
            
        """
        return self.submit_job("/predictions", cfg=cfg, shift=shift, steps=steps, width=width, height=height, prompt=prompt, sampler=sampler, scheduler=scheduler, output_format=output_format, output_quality=output_quality, negative_prompt=negative_prompt, number_of_images=number_of_images, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class whisper_diarization(FastClient):
    """
    Generated client for thomasmol/whisper-diarization
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="85d70882-606b-4083-b164-1fa4acd98a0c", api_key=api_key)
    
    def predictions(self, translate: bool = False, group_segments: bool = True, file: Optional[Union[MediaFile, str, bytes]] = None, prompt: Optional[str] = None, file_url: Optional[str] = None, language: Optional[str] = None, file_string: Optional[str] = None, num_speakers: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            translate: Translate the speech into English. Defaults to False.
            
            group_segments: Group segments of same speaker shorter apart than 2 seconds Defaults to True.
            
            file: Or an audio file Optional.
            
            prompt: Vocabulary: provide names, acronyms and loanwords in a list. Use punctuation for best accuracy. Optional.
            
            file_url: Or provide: A direct audio file URL Optional.
            
            language: Language of the spoken words as a language code like 'en'. Leave empty to auto detect language. Optional.
            
            file_string: Either provide: Base64 encoded audio file, Optional.
            
            num_speakers: Number of speakers, leave empty to autodetect. Optional.
            
        """
        return self.submit_job("/predictions", translate=translate, group_segments=group_segments, file=file, prompt=prompt, file_url=file_url, language=language, file_string=file_string, num_speakers=num_speakers, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class birefnet(FastClient):
    """
    Generated client for men1scus/birefnet
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="08229d1e-901a-45bb-97e5-6291fe34fd3d", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], resolution: str = '', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image
            
            resolution: Resolution in WxH format, e.g., '1024x1024' Defaults to ''.
            
        """
        return self.submit_job("/predictions", image=image, resolution=resolution, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class stable_diffusion_infinite_zoom(FastClient):
    """
    Generated client for arielreplicate/stable-diffusion-infinite-zoom
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="94ff68a1-11b2-4672-94ba-30572855ba8a", api_key=api_key)
    
    def predictions(self, prompt: str, inpaint_iter: int = 2, output_format: str = 'mp4', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Prompt
            
            inpaint_iter: Number of iterations of pasting the image in it's center and inpainting the boarders Defaults to 2.
            
            output_format: infinite loop gif or mp4 video Defaults to 'mp4'.
            
        """
        return self.submit_job("/predictions", prompt=prompt, inpaint_iter=inpaint_iter, output_format=output_format, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions